@@ -319,11 +319,10 @@ static int cmp_func (QofQuerySort *sort, QofSortFunc default_sort,
   return sort->obj_cmp (conva, convb);
 }
 
-static QofQuery * sortQuery = NULL;
-
-static int sort_func (gconstpointer a, gconstpointer b)
+static int sort_func (gconstpointer a, gconstpointer b, gpointer q)
 {
   int retval;
+  QofQuery *sortQuery = q;
 
   g_return_val_if_fail (sortQuery, 0);
 
@@ -686,15 +685,17 @@ void qof_query_purge_terms (QofQuery *q, GSList *param_list)
   }
 }
 
-GList * qof_query_run (QofQuery *q)
+static GList * qof_query_run_internal (QofQuery *q,
+				       void(*run_cb)(QofQueryCB*,gpointer),
+				       gpointer cb_arg)
 {
   GList *matching_objects = NULL;
-  GList *node;
   int        object_count = 0;
 
   if (!q) return NULL;
   g_return_val_if_fail (q->search_for, NULL);
   g_return_val_if_fail (q->books, NULL);
+  g_return_val_if_fail (run_cb, NULL);
   ENTER (" q=%p", q);
 
   /* XXX: Prioritize the query terms? */
@@ -707,7 +708,8 @@ GList * qof_query_run (QofQuery *q)
   }
 
   /* Maybe log this sucker */
-  if (qof_log_check (log_module, QOF_LOG_DETAIL)) qof_query_print (q);
+  if (qof_log_check (log_module, QOF_LOG_DEBUG))
+       qof_query_print (q);
 
   /* Now run the query over all the objects and save the results */
   {
@@ -716,26 +718,8 @@ GList * qof_query_run (QofQuery *q)
     memset (&qcb, 0, sizeof (qcb));
     qcb.query = q;
 
-    /* For each book */
-    for (node=q->books; node; node=node->next) 
-    {
-      QofBook *book = node->data;
-      QofBackend *be = book->backend;
-
-      /* run the query in the backend */
-      if (be) 
-      {
-        gpointer compiled_query = g_hash_table_lookup (q->be_compiled, book);
-
-        if (compiled_query && be->run_query)
-        {
-          (be->run_query) (be, compiled_query);
-        }
-      }
-
-      /* And then iterate over all the objects */
-      qof_object_foreach (q->search_for, book, (QofEntityForeachCB) check_item_cb, &qcb);
-    }
+    /* Run the query callback */
+    run_cb(&qcb, cb_arg);
 
     matching_objects = qcb.list;
     object_count = qcb.count;
@@ -750,16 +734,11 @@ GList * qof_query_run (QofQuery *q)
    */
   matching_objects = g_list_reverse(matching_objects);
 
-  /* Now sort the matching objects based on the search criteria
-   * sortQuery is an unforgivable use of static global data...  
-   * I just can't figure out how else to do this sanely.
-   */
+  /* Now sort the matching objects based on the search criteria */
   if (q->primary_sort.comp_fcn || q->primary_sort.obj_cmp ||
       (q->primary_sort.use_default && q->defaultSort))
   {
-    sortQuery = q;
-    matching_objects = g_list_sort(matching_objects, sort_func);
-    sortQuery = NULL;
+    matching_objects = g_list_sort_with_data(matching_objects, sort_func, q);
   }
 
   /* Crop the list to limit the number of splits. */
@@ -798,6 +777,67 @@ GList * qof_query_run (QofQuery *q)
   return matching_objects;
 }
 
+static void qof_query_run_cb(QofQueryCB* qcb, gpointer cb_arg)
+{
+  GList *node;
+
+  (void)cb_arg; /* unused */
+  g_return_if_fail(qcb);
+
+  for (node=qcb->query->books; node; node=node->next) 
+  {
+    QofBook *book = node->data;
+    QofBackend *be = book->backend;
+
+    /* run the query in the backend */
+    if (be) 
+    {
+      gpointer compiled_query = g_hash_table_lookup (qcb->query->be_compiled,
+						     book);
+
+      if (compiled_query && be->run_query)
+      {
+	(be->run_query) (be, compiled_query);
+      }
+    }
+
+    /* And then iterate over all the objects */
+    qof_object_foreach (qcb->query->search_for, book,
+			(QofInstanceForeachCB) check_item_cb, qcb);
+  }
+}
+
+GList * qof_query_run (QofQuery *q)
+{
+  /* Just a wrapper */
+  return qof_query_run_internal(q, qof_query_run_cb, NULL);
+}
+
+static void qof_query_run_subq_cb(QofQueryCB* qcb, gpointer cb_arg)
+{
+  QofQuery* pq = cb_arg;
+
+  g_return_if_fail(pq);
+  g_list_foreach(qof_query_last_run(pq), check_item_cb, qcb);
+}
+
+GList *
+qof_query_run_subquery (QofQuery *subq, const QofQuery* primaryq)
+{
+  if (!subq) return NULL;
+  if (!primaryq) return NULL;
+
+  /* Make sure we're searching for the same thing */
+  g_return_val_if_fail (subq->search_for, NULL);
+  g_return_val_if_fail (primaryq->search_for, NULL);
+  g_return_val_if_fail(!safe_strcmp(subq->search_for, primaryq->search_for),
+		       NULL);
+
+  /* Perform the subquery */
+  return qof_query_run_internal(subq, qof_query_run_subq_cb,
+				(gpointer)primaryq);
+}
+
 GList *
 qof_query_last_run (QofQuery *query)
 {
@@ -1208,7 +1248,7 @@ void qof_query_add_guid_list_match (QofQuery *q, GSList *param_list,
 }
 
 void qof_query_add_guid_match (QofQuery *q, GSList *param_list,
-                           const GUID *guid, QofQueryOp op)
+                               const GUID *guid, QofQueryOp op)
 {
   GList *g = NULL;
 
@@ -1235,7 +1275,7 @@ void qof_query_set_book (QofQuery *q, QofBook *book)
   slist = g_slist_prepend (slist, QOF_PARAM_GUID);
   slist = g_slist_prepend (slist, QOF_PARAM_BOOK);
   qof_query_add_guid_match (q, slist,
-                        qof_book_get_guid(book), QOF_QUERY_AND);
+                            qof_instance_get_guid(book), QOF_QUERY_AND);
 }
 
 GList * qof_query_get_books (QofQuery *q)
