@@ -24,11 +24,15 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <libguile.h>
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
 #include <locale.h>
 #include <math.h>
+#ifdef G_OS_WIN32
+#include <pow.h>
+#endif
 #include <stdarg.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -44,7 +48,6 @@
 #include "gnc-hooks.h"
 #include "gnc-module.h"
 #include "gnc-ui-util.h"
-#include "Group.h"
 #include "Transaction.h"
 #include "guile-mappings.h"
 #include "gnc-session.h"
@@ -117,18 +120,18 @@ gnc_configure_reverse_balance (void)
   }
   else if (safe_strcmp (choice, "income_expense") == 0)
   {
-    reverse_type[INCOME]  = TRUE;
-    reverse_type[EXPENSE] = TRUE;
+    reverse_type[ACCT_TYPE_INCOME]  = TRUE;
+    reverse_type[ACCT_TYPE_EXPENSE] = TRUE;
   }
   else
   {
     if (safe_strcmp (choice, "credit") != 0)
-      PERR("bad value '%s'", choice);
-    reverse_type[LIABILITY] = TRUE;
-    reverse_type[PAYABLE]   = TRUE;
-    reverse_type[EQUITY]    = TRUE;
-    reverse_type[INCOME]    = TRUE;
-    reverse_type[CREDIT]    = TRUE;
+      PERR("bad value '%s'", choice ? choice : "(null)");
+    reverse_type[ACCT_TYPE_LIABILITY] = TRUE;
+    reverse_type[ACCT_TYPE_PAYABLE]   = TRUE;
+    reverse_type[ACCT_TYPE_EQUITY]    = TRUE;
+    reverse_type[ACCT_TYPE_INCOME]    = TRUE;
+    reverse_type[ACCT_TYPE_CREDIT]    = TRUE;
   }
 
   if (choice != NULL)
@@ -173,30 +176,22 @@ gnc_reverse_balance (const Account *account)
 }
 
 
-void
-gnc_init_default_directory (char **dirname)
+gchar *
+gnc_get_default_directory (const gchar *gconf_section)
 {
-  if (*dirname == NULL)
-    *dirname = g_strdup_printf("%s/", g_get_home_dir());
+  gchar *dir;
+
+  dir = gnc_gconf_get_string (gconf_section, KEY_LAST_PATH, NULL);
+  if (!dir)
+    dir = g_strdup (g_get_home_dir ());
+
+  return dir;
 }
 
 void
-gnc_extract_directory (char **dirname, const char *filename)
+gnc_set_default_directory (const gchar *gconf_section, const gchar *directory)
 {
-  char *tmp;
-
-  if (*dirname)
-    free(*dirname);
-
-  /* Parse out the directory. */
-  if ((filename == NULL) || (strrchr(filename, '/') == NULL)) {
-    *dirname = NULL;
-    return;
-  }
-
-  *dirname = g_strdup(filename);
-  tmp = strrchr(*dirname, '/');
-  *(tmp+1) = '\0';
+  gnc_gconf_set_string(gconf_section, KEY_LAST_PATH, directory, NULL);
 }
 
 QofBook *
@@ -205,10 +200,10 @@ gnc_get_current_book (void)
   return qof_session_get_book (gnc_get_current_session ());
 }
 
-AccountGroup *
-gnc_get_current_group (void)
+Account *
+gnc_get_current_root_account (void)
 {
-  return gnc_book_get_group (gnc_get_current_book ());
+  return gnc_book_get_root_account (gnc_get_current_book ());
 }
 
 gnc_commodity_table *
@@ -373,11 +368,9 @@ gnc_ui_account_get_balance_as_of_date (Account *account,
 
   if (include_children)
   {
-    AccountGroup *children_group;
     GList *children, *node;
 
-    children_group = xaccAccountGetChildren (account);
-    children = xaccGroupGetSubAccounts (children_group);
+    children = gnc_account_get_descendants(account);
 
     for (node = children; node; node = node->next)
     {
@@ -392,6 +385,8 @@ gnc_ui_account_get_balance_as_of_date (Account *account,
         child_balance, child_currency, currency);
       balance = gnc_numeric_add_fixed (balance, child_balance);
     }
+
+    g_list_free(children);
   }
 
   /* reverse sign if needed */
@@ -418,17 +413,24 @@ gnc_ui_account_get_tax_info_string (const Account *account)
   if (get_form == SCM_UNDEFINED)
   {
     GNCModule module;
+    const gchar *tax_module;
     /* load the tax info */
 #ifdef LOCALE_SPECIFIC_TAX
-    const char *thislocale = setlocale(LC_ALL, NULL);
     /* This is a very simple hack that loads the (new, special) German
        tax definition file in a German locale, or (default) loads the
        previous US tax file. */
+# ifdef G_OS_WIN32
+    gchar *thislocale = g_win32_getlocale();
     gboolean is_de_DE = (strncmp(thislocale, "de_DE", 5) == 0);
-#else
+    g_free(thislocale);
+# else /* !G_OS_WIN32 */
+    const char *thislocale = setlocale(LC_ALL, NULL);
+    gboolean is_de_DE = (strncmp(thislocale, "de_DE", 5) == 0);
+# endif /* G_OS_WIN32 */
+#else /* LOCALE_SPECIFIC_TAX */
     gboolean is_de_DE = FALSE;
 #endif /* LOCALE_SPECIFIC_TAX */
-    const char *tax_module = is_de_DE ? 
+    tax_module = is_de_DE ? 
       "gnucash/tax/de_DE" : 
       "gnucash/tax/us";
 
@@ -450,14 +452,14 @@ gnc_ui_account_get_tax_info_string (const Account *account)
     return NULL;
 
   atype = xaccAccountGetType (account);
-  if (atype != INCOME && atype != EXPENSE)
+  if (atype != ACCT_TYPE_INCOME && atype != ACCT_TYPE_EXPENSE)
     return NULL;
 
   code = xaccAccountGetTaxUSCode (account);
   if (!code)
     return NULL;
 
-  category = scm_c_eval_string (atype == INCOME ?
+  category = scm_c_eval_string (atype == ACCT_TYPE_INCOME ?
 				"txf-income-categories" :
 				"txf-expense-categories");
 
@@ -572,10 +574,9 @@ equity_base_name (GNCEquityType equity_type)
 }
 
 Account *
-gnc_find_or_create_equity_account (AccountGroup *group,
+gnc_find_or_create_equity_account (Account *root,
                                    GNCEquityType equity_type,
-                                   gnc_commodity *currency,
-                                   QofBook *book)
+                                   gnc_commodity *currency)
 {
   Account *parent;
   Account *account;
@@ -587,20 +588,20 @@ gnc_find_or_create_equity_account (AccountGroup *group,
   g_return_val_if_fail (equity_type >= 0, NULL);
   g_return_val_if_fail (equity_type < NUM_EQUITY_TYPES, NULL);
   g_return_val_if_fail (currency != NULL, NULL);
-  g_return_val_if_fail (group != NULL, NULL);
+  g_return_val_if_fail (root != NULL, NULL);
 
   base_name = equity_base_name (equity_type);
 
-  account = xaccGetAccountFromName (group, base_name);
-  if (account && xaccAccountGetType (account) != EQUITY)
+  account = gnc_account_lookup_by_name(root, base_name);
+  if (account && xaccAccountGetType (account) != ACCT_TYPE_EQUITY)
     account = NULL;
 
   if (!account)
   {
     base_name = base_name && *base_name ? _(base_name) : "";
 
-    account = xaccGetAccountFromName (group, base_name);
-    if (account && xaccAccountGetType (account) != EQUITY)
+    account = gnc_account_lookup_by_name(root, base_name);
+    if (account && xaccAccountGetType (account) != ACCT_TYPE_EQUITY)
       account = NULL;
   }
 
@@ -612,8 +613,8 @@ gnc_find_or_create_equity_account (AccountGroup *group,
 
   name = g_strconcat (base_name, " - ",
                       gnc_commodity_get_mnemonic (currency), NULL);
-  account = xaccGetAccountFromName (group, name);
-  if (account && xaccAccountGetType (account) != EQUITY)
+  account = gnc_account_lookup_by_name(root, name);
+  if (account && xaccAccountGetType (account) != ACCT_TYPE_EQUITY)
     account = NULL;
 
   name_exists = (account != NULL);
@@ -637,26 +638,22 @@ gnc_find_or_create_equity_account (AccountGroup *group,
     name = g_strdup (base_name);
   }
 
-  parent = xaccGetAccountFromName (group, _("Equity"));
-  if (parent && xaccAccountGetType (parent) != EQUITY)
-    parent = NULL;
+  parent = gnc_account_lookup_by_name(root, _("Equity"));
+  if (!parent || xaccAccountGetType (parent) != ACCT_TYPE_EQUITY)
+    parent = root;
+  g_assert(parent);
 
-  account = xaccMallocAccount (book);
+  account = xaccMallocAccount (gnc_account_get_book(root));
 
   xaccAccountBeginEdit (account);
 
   xaccAccountSetName (account, name);
-  xaccAccountSetType (account, EQUITY);
+  xaccAccountSetType (account, ACCT_TYPE_EQUITY);
   xaccAccountSetCommodity (account, currency);
 
-  if (parent)
-  {
-    xaccAccountBeginEdit (parent);
-    xaccAccountInsertSubAccount (parent, account);
-    xaccAccountCommitEdit (parent);
-  }
-  else
-    xaccGroupInsertAccount (group, account);
+  xaccAccountBeginEdit (parent);
+  gnc_account_append_child (parent, account);
+  xaccAccountCommitEdit (parent);
 
   xaccAccountCommitEdit (account);
 
@@ -681,10 +678,9 @@ gnc_account_create_opening_balance (Account *account,
   g_return_val_if_fail (account != NULL, FALSE);
 
   equity_account =
-    gnc_find_or_create_equity_account (xaccAccountGetRoot (account),
+    gnc_find_or_create_equity_account (gnc_account_get_root(account),
                                        EQUITY_OPENING_BALANCE,
-                                       xaccAccountGetCommodity (account),
-                                       book);
+                                       xaccAccountGetCommodity (account));
   if (!equity_account)
     return FALSE;
 
@@ -736,18 +732,34 @@ static void
 gnc_lconv_set_utf8 (char **p_value, char *default_value)
 {
   char *value = *p_value;
+  *p_value = NULL;
 
   if ((value == NULL) || (value[0] == 0))
-    *p_value = default_value;
+    value = default_value;
 
-  *p_value = g_locale_to_utf8 (*p_value, -1, NULL, NULL, NULL);
+#ifdef G_OS_WIN32
+  {
+    /* get number of resulting wide characters */
+    size_t count = mbstowcs (NULL, value, 0);
+    if (count > 0) {
+      /* malloc and convert */
+      wchar_t *wvalue = g_malloc ((count+1) * sizeof(wchar_t));
+      count = mbstowcs (wvalue, value, count+1);
+      if (count > 0) {
+        *p_value = g_utf16_to_utf8 (wvalue, -1, NULL, NULL, NULL);
+      }
+      g_free (wvalue);
+    }
+  }
+#else /* !G_OS_WIN32 */
+  *p_value = g_locale_to_utf8 (value, -1, NULL, NULL, NULL);
+#endif
+  
   if (*p_value == NULL) {
     // The g_locale_to_utf8 conversion failed. FIXME: Should we rather
     // use an empty string instead of the default_value? Not sure.
     *p_value = default_value;
   }
-  // FIXME: Do we really need to make a copy here ?
-  //*p_value = g_strdup (*p_value);
 }
 
 static void
@@ -777,6 +789,7 @@ gnc_localeconv (void)
   gnc_lconv_set_utf8(&lc.mon_thousands_sep, ",");
   gnc_lconv_set_utf8(&lc.mon_grouping, "\003");
   gnc_lconv_set_utf8(&lc.negative_sign, "-");
+  gnc_lconv_set_utf8(&lc.positive_sign, "");
 
   gnc_lconv_set_char(&lc.frac_digits, 2);
   gnc_lconv_set_char(&lc.int_frac_digits, 2);
@@ -826,6 +839,13 @@ gnc_locale_default_currency_nodefault (void)
 
   currency = gnc_commodity_table_lookup (table, GNC_COMMODITY_NS_CURRENCY, code);
 
+  /* Some very old locales (notably on win32) still announce a euro
+     currency as default, although it has been replaced by EUR in
+     2001. We use EUR as default in that case, but the user can always
+     override from gconf. */
+  if (gnc_is_euro_currency (currency))
+    currency = gnc_get_euro();
+
   return (currency ? currency : NULL);
 }
 
@@ -856,10 +876,10 @@ gnc_default_currency (void)
     mnemonic = gnc_gconf_get_string(GCONF_GENERAL, KEY_CURRENCY_OTHER, NULL);
     currency = gnc_commodity_table_lookup(gnc_get_current_commodities(),
 					  GNC_COMMODITY_NS_CURRENCY, mnemonic);
-    DEBUG("mnemonic %s, result %p", mnemonic, currency);
+    DEBUG("mnemonic %s, result %p", mnemonic ? mnemonic : "(null)", currency);
     g_free(mnemonic);
-    g_free(choice);
   }
+  g_free(choice);
 
   if (!currency)
     currency = gnc_locale_default_currency ();
@@ -888,10 +908,10 @@ gnc_default_report_currency (void)
 				    KEY_CURRENCY_OTHER, NULL);
     currency = gnc_commodity_table_lookup(gnc_get_current_commodities(),
 					  GNC_COMMODITY_NS_CURRENCY, mnemonic);
-    DEBUG("mnemonic %s, result %p", mnemonic, currency);
-    g_free(choice);
+    DEBUG("mnemonic %s, result %p", mnemonic ? mnemonic : "(null)", currency);
     g_free(mnemonic);
   }
+  g_free(choice);
 
   if (!currency)
     currency = gnc_locale_default_currency (); 
@@ -1358,13 +1378,15 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
     guint8 num_decimal_places = 0;
     char *temp_ptr = temp_buf;
 
-    decimal_point = info->monetary ?
-      lc->mon_decimal_point : lc->decimal_point;
+    decimal_point = info->monetary
+        ? lc->mon_decimal_point
+        : lc->decimal_point;
     g_utf8_strncpy(temp_ptr, decimal_point, 1);
     temp_ptr = g_utf8_find_next_char(temp_ptr, NULL);
 
-    while (!gnc_numeric_zero_p (val) && (val.denom != 1) &&
-	   (num_decimal_places < max_dp))
+    while (!gnc_numeric_zero_p (val)
+           && (val.denom != 1)
+           && (num_decimal_places < max_dp))
     {
       gint64 digit;
 
@@ -1562,6 +1584,157 @@ xaccPrintAmount (gnc_numeric val, GNCPrintAmountInfo info)
 }
 
 
+/********************************************************************\
+ ********************************************************************/
+
+#define FUDGE .00001
+
+/* This function is basically untranslatable. I'd
+   guess out of the 29 translations we have, 20 will have their number
+   wordings in a totally different way than English has (not to
+   mention gender-dependent number endings). Which means this
+   word-by-word translation will be useless or even plain
+   wrong. For this reason, we don't even start to pretend a
+   word-by-word translation would be of any use, so we don't mark any
+   of these strings for translation. cstim, 2007-04-15. */
+static gchar *small_numbers[] = {
+  /* Translators: This section is for generating the "amount, in
+     words" field when printing a check. This function gets the
+     wording right for English, but unfortunately not for most other
+     languages. Decide for yourself whether the check printing is
+     actually needed in your language; if not, you can safely skip the
+     translation of all of these strings.  */
+  "Zero", "One", "Two", "Three", "Four",
+  "Five", "Six", "Seven", "Eight", "Nine",
+  "Ten", "Eleven", "Twelve", "Thirteen", "Fourteen",
+  "Fifteen", "Sixteen", "Seventeen", "Eighteen", "Nineteen",
+  "Twenty"};
+static gchar *medium_numbers[] = {
+  "Zero", "Ten", "Twenty", "Thirty", "Forty",
+  "Fifty", "Sixty", "Seventy", "Eighty", "Ninety"};
+static gchar *big_numbers[] = {
+  /* Translators: This is the word for the number 10^2 */
+  "Hundred",
+  /* Translators: This is the word for the number 10^3 */
+  "Thousand",
+  /* Translators: This is the word for the number 10^6, one thousand
+     thousands. */
+  "Million",
+  /* Translators: This is the word for the number 10^9, one thousand
+     millions. WATCH OUT: In British english and many other languages
+     this word is used for 10^12 which is one million millions! In
+     contrast to this, here in GnuCash this is used in the American
+     english meaning of 10^9.  */
+  "Billion",
+  /* Translators: This is the word for the number 10^12, one million
+     millions. */
+  "Trillion",
+  /* Translators: This is the word for the number 10^15 */
+  "Quadrillion",
+  /* Translators: This is the word for the number 10^18 */
+  "Quintillion"};
+
+static gchar *
+integer_to_words(gint64 val)
+{
+  gint64 log_val, pow_val, this_part;
+  GString *result;
+  gchar *tmp;
+
+  if (val == 0)
+    return g_strdup("zero");
+  if (val < 0)
+    val = -val;
+
+  result = g_string_sized_new(100);
+
+  while (val >= 1000) {
+    log_val = log10(val) / 3 + FUDGE;
+    pow_val = exp(log_val * 3 * G_LN10) + FUDGE;
+    this_part = val / pow_val;
+    val -= this_part * pow_val;
+    tmp = integer_to_words(this_part);
+    g_string_append_printf(result, "%s %s ", tmp,
+                           gettext(big_numbers[log_val]));
+    g_free(tmp);
+  }
+
+  if (val >= 100) {
+    this_part = val / 100;
+    val -= this_part * 100;
+    g_string_append_printf(result, "%s %s ",
+                           gettext(small_numbers[this_part]),
+                           gettext(big_numbers[0]));
+  }
+
+  if (val > 20) {
+    this_part = val / 10;
+    val -= this_part * 10;
+    g_string_append(result, gettext(medium_numbers[this_part]));
+    g_string_append_c(result, ' ');
+  }
+
+  if (val > 0) {
+    this_part = val;
+    val -= this_part;
+    g_string_append(result, gettext(small_numbers[this_part]));
+    g_string_append_c(result, ' ');
+  }
+
+  result = g_string_truncate(result, result->len - 1);
+  return g_string_free(result, FALSE);
+}
+
+gchar *
+number_to_words(gdouble val, gint64 denom)
+{
+  gint64 int_part, frac_part;
+  gchar *int_string, *nomin_string, *denom_string, *full_string;
+
+  if (val < 0) val = -val;
+  if (denom < 0) denom = -denom;
+
+  int_part = trunc(val);
+  frac_part = round((val - int_part) * denom);
+
+  int_string = integer_to_words(int_part);
+  /* Inside of the gettext macro _(...) we must not use any macros but
+     only plain string literals. For this reason, convert the strings
+     separately. */
+  nomin_string = g_strdup_printf("%" G_GINT64_FORMAT, frac_part);
+  denom_string = g_strdup_printf("%" G_GINT64_FORMAT, denom);
+  full_string =
+    /* Translators: This is for the "amount, in words" field in check
+       printing. The first %s is the integer amount of dollars (or
+       whatever currency), the second and third %s the cent amount as
+       a fraction, e.g. 47/100.  */
+    g_strdup_printf("%s and %s/%s",
+		    int_string, nomin_string, denom_string);
+  g_free(int_string);
+  g_free(nomin_string);
+  g_free(denom_string);
+  return full_string;
+}
+
+gchar *
+numeric_to_words(gnc_numeric val)
+{
+  return number_to_words(gnc_numeric_to_double(val),
+                         gnc_numeric_denom(val));
+}
+
+const gchar *
+printable_value (gdouble val, gint denom)
+{
+  GNCPrintAmountInfo info;
+  gnc_numeric num;
+
+  num = gnc_numeric_create(round(val * denom), denom);
+  info = gnc_share_print_info_places(log10(denom));
+  return xaccPrintAmount (num, info);
+}
+
+
 /********************************************************************\
  * xaccParseAmount                                                  *
  *   parses amount strings using locale data                        *
