@@ -210,7 +210,7 @@ int finishQuery(PGBackend *be);
  * -- sqlname -- input -- the name of the field in the sql table
  * -- fun -- input -- a subroutine returning a value
  * -- ndiffs -- input/output -- integer, incremented if the 
- *              value ofthe field and the value returned by
+ *              value of the field and the value returned by
  *              the subroutine differ.
  *
  * The different macros compare different field types.
@@ -245,7 +245,7 @@ int finishQuery(PGBackend *be);
 }
 
 /* Compare guids. A NULL GUID from the engine is considered to 
- * match any value of a GUID in teh sql database.  This is 
+ * match any value of a GUID in the sql database.  This is 
  * equality is used to enable deletion, where the GUID may have
  * already been set to NULL in the engine, but not yet in the DB.
  */
@@ -358,7 +358,7 @@ int finishQuery(PGBackend *be);
       for (node=be->blist; node; node=node->next)                \
       {                                                          \
          book = node->data;                                      \
-         if (guid_equal (qof_entity_get_guid((QofEntity*)book), &book_guid)) break; \
+         if (guid_equal (qof_entity_get_guid((QofInstance*)book), &book_guid)) break; \
          book = NULL;                                            \
       }                                                          \
       if (!book) return data;                                    \
