@@ -31,8 +31,6 @@
  
 #include "Account.h"
 #include "AccountP.h"
-#include "Group.h"
-#include "GroupP.h"
 #include "gnc-commodity.h"
 #include "gnc-engine.h"
 #include "gnc-pricedb.h"
@@ -135,6 +133,7 @@ pgendStoreTransactionNoLock (PGBackend *be, Transaction *trans,
                              gboolean do_check_version)
 {
    GList *start, *deletelist=NULL, *node;
+   guint32 s_idata, t_idata;
    char * p;
 
    if (!be || !trans) return;
@@ -145,8 +144,8 @@ pgendStoreTransactionNoLock (PGBackend *be, Transaction *trans,
    {
       if (0 < pgendTransactionCompareVersion (be, trans)) return;
    }
-   trans->version ++;  /* be sure to update the version !! */
-   trans->version_check = be->version_check;
+   /* be sure to update the version !! */
+   qof_instance_increment_version(trans, be->version_check);
 
    /* first, we need to see which splits are in the database
     * since what is there may not match what we have cached in 
@@ -173,7 +172,7 @@ pgendStoreTransactionNoLock (PGBackend *be, Transaction *trans,
         {
           Split *s = split_node->data;
 
-          if (s && guid_equal (&s->inst.entity.guid, &dti->guid))
+          if (s && guid_equal (qof_instance_get_guid(s), &dti->guid))
           {
             pgendStoreAuditSplit (be, s, SQL_DELETE);
             break;
@@ -213,31 +212,36 @@ pgendStoreTransactionNoLock (PGBackend *be, Transaction *trans,
    /* Update the rest */
    start = xaccTransGetSplitList(trans);
 
-   PINFO ("split-list=%p, do_free=%d", start, trans->inst.do_free);
-   if ((start) && !(trans->inst.do_free))
+   PINFO ("split-list=%p, destroying=%d", start,
+          qof_instance_get_destroying(trans));
+   if ((start) && !qof_instance_get_destroying(trans))
    {
       gnc_commodity *com;
 
       for (node=start; node; node=node->next) 
       {
          Split * s = node->data;
-         if ((0 == s->idata) &&
+         s_idata = qof_instance_get_idata(s);
+         if ((0 == s_idata) &&
              (FALSE == kvp_frame_is_empty (xaccSplitGetSlots(s))))
          {
-            s->idata = pgendNewGUIDidx(be);
+            s_idata = pgendNewGUIDidx(be);
+            qof_instance_set_idata(s, s_idata);
          }
          pgendPutOneSplitOnly (be, s);
-         if (s->idata)
+         if (s_idata)
          {
-           pgendKVPDelete (be, s->idata);
-           pgendKVPStore (be, s->idata, s->inst.kvp_data);
+           pgendKVPDelete (be, s_idata);
+           pgendKVPStore (be, s_idata, s->inst.kvp_data);
          }
       }
 
-      if ((0 == trans->idata) &&
+      t_idata = qof_instance_get_idata(trans);
+      if ((0 == t_idata) &&
           (FALSE == kvp_frame_is_empty (xaccTransGetSlots(trans))))
       {
-         trans->idata = pgendNewGUIDidx(be);
+         t_idata = pgendNewGUIDidx(be);
+         qof_instance_set_idata(trans, t_idata);
       }
 
       /* Make sure the commodity is in the table.
@@ -247,10 +251,10 @@ pgendStoreTransactionNoLock (PGBackend *be, Transaction *trans,
 
       pgendPutOneTransactionOnly (be, trans);
 
-      if (trans->idata)
+      if (t_idata)
       {
-        pgendKVPDelete (be, trans->idata);
-        pgendKVPStore (be, trans->idata, trans->inst.kvp_data);
+        pgendKVPDelete (be, t_idata);
+        pgendKVPStore (be, t_idata, trans->inst.kvp_data);
       }
    }
    else
@@ -283,9 +287,11 @@ pgendStoreTransactionNoLock (PGBackend *be, Transaction *trans,
       for (node=start; node; node=node->next) 
       {
          Split * s = node->data;
-         if (0 != s->idata) pgendKVPDelete (be, s->idata);
+         s_idata = qof_instance_get_idata(s);
+         if (0 != s_idata) pgendKVPDelete (be, s_idata);
       }
-      if (0 != trans->idata) pgendKVPDelete (be, trans->idata);
+      t_idata = qof_instance_get_idata(trans);
+      if (0 != t_idata) pgendKVPDelete (be, t_idata);
    }
 
    LEAVE(" ");
@@ -350,11 +356,11 @@ trans_traverse_cb (Transaction *trans, void *cb_data)
 
 
 void
-pgendStoreAllTransactions (PGBackend *be, AccountGroup *grp)
+pgendStoreAllTransactions (PGBackend *be, Account *root)
 {
    char *p;
-   ENTER ("be=%p, grp=%p", be, grp);
-   if (!be || !grp) return;
+   ENTER ("be=%p, root=%p", be, root);
+   if (!be || !root) return;
 
    /* lock it up so that we store atomically */
    p = "BEGIN;\n"
@@ -365,8 +371,8 @@ pgendStoreAllTransactions (PGBackend *be, AccountGroup *grp)
 
    /* Recursively walk transactions. Start by reseting the write 
     * flags. We use this to avoid infinite recursion */
-   xaccGroupBeginStagedTransactionTraversals(grp);
-   xaccGroupStagedTransactionTraversal (grp, 1, trans_traverse_cb, be);
+   gnc_account_tree_begin_staged_transaction_traversals(root);
+   gnc_account_tree_staged_transaction_traversal (root, 1, trans_traverse_cb, be);
 
    p = "COMMIT;\n"
        "NOTIFY gncTransaction;";
@@ -378,7 +384,7 @@ pgendStoreAllTransactions (PGBackend *be, AccountGroup *grp)
    if ((MODE_POLL == be->session_mode) ||
        (MODE_EVENT == be->session_mode))
    {
-      pgendGroupRecomputeAllCheckpoints(be, grp);
+      pgendAccountTreeRecomputeAllCheckpoints(be, root);
    }
    LEAVE(" ");
 }
@@ -468,7 +474,7 @@ pgendCopySplitsToEngine (PGBackend *be, Transaction *trans)
             s = pgendSplitLookup (be, &guid);
             if (!s)
             {
-               s = xaccMallocSplit(trans->inst.book);
+               s = xaccMallocSplit(qof_instance_get_book(trans));
                xaccSplitSetGUID(s, &guid);
             }
 
@@ -480,7 +486,7 @@ pgendCopySplitsToEngine (PGBackend *be, Transaction *trans)
             xaccSplitSetDateReconciledTS (s, &ts);
 
             xaccSplitSetReconcile (s, (DB_GET_VAL("reconciled", j))[0]);
-            s->idata = atoi(DB_GET_VAL("iguid",j));
+            qof_instance_set_idata(s, atoi(DB_GET_VAL("iguid",j)));
 
             /* --------------------------------------------- */
             /* next, find the account that this split goes into */
@@ -503,8 +509,6 @@ pgendCopySplitsToEngine (PGBackend *be, Transaction *trans)
 
             if (acc)
             {
-              int save_state;
-
               if (acc != previous_acc)
               {
                 xaccAccountCommitEdit (previous_acc);
@@ -512,15 +516,7 @@ pgendCopySplitsToEngine (PGBackend *be, Transaction *trans)
                 previous_acc = acc;
               }
 
-              if (acc->parent)
-                save_state = acc->parent->saved;
-              else
-                save_state = 1;
-
               xaccAccountInsertSplit(acc, s);
-
-              if (acc->parent)
-                acc->parent->saved = save_state;
             }
 
             /* It's ok to set value without an account, since
@@ -570,21 +566,12 @@ pgendCopySplitsToEngine (PGBackend *be, Transaction *trans)
      if (account)
      {
        gnc_numeric amount;
-       int save_state;
        int acct_frac;
 
-       if (account->parent)
-         save_state = account->parent->saved;
-       else
-         save_state = 1;
-
        xaccAccountBeginEdit (account);
        xaccAccountInsertSplit (account, sri->split);
        xaccAccountCommitEdit (account);
 
-       if (account->parent)
-         account->parent->saved = save_state;
-
        acct_frac = xaccAccountGetCommoditySCU (account);
        amount = gnc_numeric_create (sri->amount, acct_frac);
        xaccSplitSetAmount (sri->split, amount);
@@ -652,6 +639,7 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
    int engine_data_is_newer = 0;
    int j;
    GList *node, *engine_splits;
+   guint32 s_idata, t_idata;
    
    ENTER ("be=%p", be);
    if (!be || !trans_guid) return 0;
@@ -672,7 +660,7 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
    {
       /* save some performance, don't go to the
          backend if the data is recent. */
-      if (MAX_VERSION_AGE >= be->version_check - trans->version_check) 
+      if (MAX_VERSION_AGE >= be->version_check - qof_instance_get_version_check(trans)) 
       {
          PINFO ("fresh data, skip check");
          pgendEnable(be);
@@ -735,7 +723,7 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
      {
        gint32 db_version, cache_version;
        db_version = atoi (DB_GET_VAL("version",j));
-       cache_version = xaccTransGetVersion (trans);
+       cache_version = qof_instance_get_version (trans);
        if (db_version == cache_version) {
          engine_data_is_newer = 0;
        } else 
@@ -773,16 +761,16 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
        xaccTransSetDatePostedTS (trans, &ts);
        ts = gnc_iso8601_to_timespec_gmt (DB_GET_VAL("date_entered",j));
        xaccTransSetDateEnteredTS (trans, &ts);
-       xaccTransSetVersion (trans, atoi(DB_GET_VAL("version",j)));
+       qof_instance_set_version (trans, atoi(DB_GET_VAL("version",j)));
        xaccTransSetCurrency (trans, currency);
-       trans->idata = atoi(DB_GET_VAL("iguid",j));
+       qof_instance_set_idata(trans, atoi(DB_GET_VAL("iguid",j)));
      }
    }
 
    PQclear (result);
 
    /* set timestamp as 'recent' for this data */
-   trans->version_check = be->version_check;
+   qof_instance_set_version_check(trans, be->version_check);
 
    /* if engine data was newer, we are done */
    if (0 <= engine_data_is_newer) 
@@ -802,7 +790,8 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
    /* ------------------------------------------------- */
    /* restore any kvp data associated with the transaction and splits */
 
-   if (0 != trans->idata)
+   t_idata = qof_instance_get_idata(trans);
+   if (0 != t_idata)
    {
       if (!kvp_frame_is_empty (trans->inst.kvp_data))
       {
@@ -810,14 +799,15 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
         trans->inst.kvp_data = kvp_frame_new ();
       }
 
-      trans->inst.kvp_data = pgendKVPFetch (be, trans->idata, trans->inst.kvp_data);
+      trans->inst.kvp_data = pgendKVPFetch (be, t_idata, trans->inst.kvp_data);
    }
 
    engine_splits = xaccTransGetSplitList(trans);
    for (node = engine_splits; node; node=node->next)
    {
       Split *s = node->data;
-      if (0 != s->idata)
+      s_idata = qof_instance_get_idata(s);
+      if (0 != s_idata)
       {
          if (!kvp_frame_is_empty (s->inst.kvp_data))
          {
@@ -825,7 +815,7 @@ pgendCopyTransactionToEngine (PGBackend *be, const GUID *trans_guid)
            s->inst.kvp_data = kvp_frame_new ();
          }
 
-         s->inst.kvp_data = pgendKVPFetch (be, s->idata, s->inst.kvp_data);
+         s->inst.kvp_data = pgendKVPFetch (be, s_idata, s->inst.kvp_data);
       }
    }
 
@@ -998,7 +988,7 @@ pgend_trans_commit_edit (QofBackend * bend,
                   "\ttransaction is '%s' %s\n",
                   xaccTransGetDescription (trans), buf);
             rollback = 0;
-            trans->inst.do_free = TRUE;
+            qof_instance_set_destroying(trans, TRUE);
          }
          else
          {
@@ -1053,19 +1043,6 @@ pgend_trans_commit_edit (QofBackend * bend,
       pgendTransactionRecomputeCheckpoints (be, trans);
    }
 
-   /* hack alert -- the following code will get rid of that annoying
-    * message from the GUI about saving one's data. However, it doesn't
-    * do the right thing if the connection to the backend was ever lost.
-    * what should happen is the user should get a chance to
-    * resynchronize their data with the backend, before quiting out.
-    */
-   {
-      Split * s = xaccTransGetSplit (trans, 0);
-      Account *acc = xaccSplitGetAccount (s);
-      AccountGroup *top = xaccAccountGetRoot (acc);
-      xaccGroupMarkSaved (top);
-   }
-
    LEAVE ("commited");
    return;
 }
