@@ -2,22 +2,38 @@
  * dialog-customer.c -- Dialog for Customer entry
  * Copyright (C) 2001 Derek Atkins
  * Author: Derek Atkins <warlord@MIT.EDU>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, contact:
+ *
+ * Free Software Foundation           Voice:  +1-617-542-5942
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org
  */
 
 #include "config.h"
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include "dialog-utils.h"
-#include "global-options.h"
 #include "gnc-amount-edit.h"
 #include "gnc-currency-edit.h"
 #include "gnc-component-manager.h"
 #include "gnc-ui.h"
 #include "gnc-gui-query.h"
 #include "gnc-ui-util.h"
-#include "gnc-engine-util.h"
-#include "window-help.h"
+#include "qof.h"
 
 #include "dialog-search.h"
 #include "search-param.h"
@@ -36,6 +52,17 @@
 #define DIALOG_NEW_CUSTOMER_CM_CLASS "dialog-new-customer"
 #define DIALOG_EDIT_CUSTOMER_CM_CLASS "dialog-edit-customer"
 
+#define GCONF_SECTION_SEARCH "dialogs/business/customer_search"
+
+void gnc_customer_taxtable_check_cb (GtkToggleButton *togglebutton,
+				     gpointer user_data);
+
+void gnc_customer_window_ok_cb (GtkWidget *widget, gpointer data);
+void gnc_customer_window_cancel_cb (GtkWidget *widget, gpointer data);
+void gnc_customer_window_help_cb (GtkWidget *widget, gpointer data);
+void gnc_customer_window_destroy_cb (GtkWidget *widget, gpointer data);
+void gnc_customer_name_changed_cb (GtkWidget *widget, gpointer data);
+
 typedef enum
 {
   NEW_CUSTOMER,
@@ -94,7 +121,7 @@ struct _customer_window {
   GncTaxTable *	taxtable;
 };
 
-static void
+void
 gnc_customer_taxtable_check_cb (GtkToggleButton *togglebutton,
 				gpointer user_data)
 {
@@ -117,6 +144,9 @@ cw_get_customer (CustomerWindow *cw)
 
 static void gnc_ui_to_customer (CustomerWindow *cw, GncCustomer *cust)
 {
+  GtkTextBuffer* text_buffer;
+  GtkTextIter start, end;
+  gchar *text;
   GncAddress *addr, *shipaddr;
 
   addr = gncCustomerGetAddr (cust);
@@ -168,8 +198,11 @@ static void gnc_ui_to_customer (CustomerWindow *cw, GncCustomer *cust)
   gncCustomerSetActive (cust, gtk_toggle_button_get_active
 			(GTK_TOGGLE_BUTTON (cw->active_check)));
   gncCustomerSetTaxIncluded (cust, cw->taxincluded);
-  gncCustomerSetNotes (cust, gtk_editable_get_chars
-		       (GTK_EDITABLE (cw->notes_text), 0, -1));
+
+  text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(cw->notes_text));
+  gtk_text_buffer_get_bounds (text_buffer, &start, &end);
+  text = gtk_text_buffer_get_text (text_buffer, &start, &end, FALSE);
+  gncCustomerSetNotes (cust, text);
 
   /* Parse and set the currency, terms, discount, and credit amounts */
   gncCustomerSetCurrency (cust,
@@ -195,7 +228,7 @@ static gboolean check_edit_amount (GtkWidget *dialog, GtkWidget *amount,
 {
   if (!gnc_amount_edit_evaluate (GNC_AMOUNT_EDIT (amount))) {
     if (error_message)
-      gnc_error_dialog_parented (GTK_WINDOW (dialog), "%s", error_message);
+      gnc_error_dialog (dialog, "%s", error_message);
     return TRUE;
   }
   /* We've got a valid-looking number; check mix/max */
@@ -204,7 +237,7 @@ static gboolean check_edit_amount (GtkWidget *dialog, GtkWidget *amount,
     if ((min && gnc_numeric_compare (*min, val) > 0) ||
 	(max && gnc_numeric_compare (val, *max) > 0)) {
       if (error_message)
-	gnc_error_dialog_parented (GTK_WINDOW (dialog), "%s", error_message);
+	gnc_error_dialog (dialog, "%s", error_message);
       return TRUE;
     }
   }
@@ -217,21 +250,22 @@ static gboolean check_entry_nonempty (GtkWidget *dialog, GtkWidget *entry,
   const char *res = gtk_entry_get_text (GTK_ENTRY (entry));
   if (safe_strcmp (res, "") == 0) {
     if (error_message)
-      gnc_error_dialog_parented (GTK_WINDOW (dialog), "%s", error_message);
+      gnc_error_dialog (dialog, "%s", error_message);
     return TRUE;
   }
   return FALSE;
 }
 
-static void
+void
 gnc_customer_window_ok_cb (GtkWidget *widget, gpointer data)
 {
   CustomerWindow *cw = data;
   gnc_numeric min, max;
+  gchar *string;
 
   /* Check for valid company name */
   if (check_entry_nonempty (cw->dialog, cw->company_entry,
-		   _("You must enter a company name.\n"
+		   _("You must enter a company name. "
 		     "If this customer is an individual (and not a company) "
 		     "you should set the \"company name\" and \"contact name\" "
 		     "the same.")))
@@ -243,7 +277,7 @@ gnc_customer_window_ok_cb (GtkWidget *widget, gpointer data)
       check_entry_nonempty (cw->dialog, cw->addr3_entry, NULL) &&
       check_entry_nonempty (cw->dialog, cw->addr4_entry, NULL)) {
     const char *msg = _("You must enter a billing address.");
-    gnc_error_dialog_parented (GTK_WINDOW (cw->dialog), msg);
+    gnc_error_dialog (cw->dialog, msg);
     return;
   }
 
@@ -263,9 +297,10 @@ gnc_customer_window_ok_cb (GtkWidget *widget, gpointer data)
 
   /* Set the customer id if one has not been chosen */
   if (safe_strcmp (gtk_entry_get_text (GTK_ENTRY (cw->id_entry)), "") == 0) {
-    gtk_entry_set_text (GTK_ENTRY (cw->id_entry),
-			g_strdup_printf ("%.6lld",
-					 gncCustomerNextID (cw->book)));
+    string = g_strdup_printf ("%.6" G_GINT64_FORMAT,
+			      gncCustomerNextID (cw->book));
+    gtk_entry_set_text (GTK_ENTRY (cw->id_entry), string);
+    g_free(string);
   }
 
   /* Now save it off */
@@ -281,7 +316,7 @@ gnc_customer_window_ok_cb (GtkWidget *widget, gpointer data)
   gnc_close_gui_component (cw->component_id);
 }
 
-static void
+void
 gnc_customer_window_cancel_cb (GtkWidget *widget, gpointer data)
 {
   CustomerWindow *cw = data;
@@ -289,15 +324,13 @@ gnc_customer_window_cancel_cb (GtkWidget *widget, gpointer data)
   gnc_close_gui_component (cw->component_id);
 }
 
-static void
+void
 gnc_customer_window_help_cb (GtkWidget *widget, gpointer data)
 {
-  char *help_file = HH_CUSTOMER;
-
-  helpWindow(NULL, NULL, help_file);
+  gnc_gnome_help(HF_HELP, HL_USAGE);
 }
 
-static void
+void
 gnc_customer_window_destroy_cb (GtkWidget *widget, gpointer data)
 {
   CustomerWindow *cw = data;
@@ -317,11 +350,12 @@ gnc_customer_window_destroy_cb (GtkWidget *widget, gpointer data)
   g_free (cw);
 }
 
-static void
+void
 gnc_customer_name_changed_cb (GtkWidget *widget, gpointer data)
 {
   CustomerWindow *cw = data;
-  char *name, *id, *fullname, *title;
+  char *fullname, *title;
+  const char *id,  *name;
 
   if (!cw)
     return;
@@ -332,12 +366,12 @@ gnc_customer_name_changed_cb (GtkWidget *widget, gpointer data)
 
   id = gtk_entry_get_text (GTK_ENTRY (cw->id_entry));
 
-  fullname = g_strconcat (name, " (", id, ")", NULL);
+  fullname = g_strconcat (name, " (", id, ")", (char *)NULL);
 
   if (cw->dialog_type == EDIT_CUSTOMER)
-    title = g_strconcat (_("Edit Customer"), " - ", fullname, NULL);
+    title = g_strconcat (_("Edit Customer"), " - ", fullname, (char *)NULL);
   else
-    title = g_strconcat (_("New Customer"), " - ", fullname, NULL);
+    title = g_strconcat (_("New Customer"), " - ", fullname, (char *)NULL);
 
   gtk_window_set_title (GTK_WINDOW (cw->dialog), title);
 
@@ -350,7 +384,9 @@ gnc_customer_window_close_handler (gpointer user_data)
 {
   CustomerWindow *cw = user_data;
 
-  gnome_dialog_close (GNOME_DIALOG (cw->dialog));
+  gtk_widget_destroy (cw->dialog);
+  // cw has already been freed by this point.
+  // cw->dialog = NULL;
 }
 
 static void
@@ -369,7 +405,7 @@ gnc_customer_window_refresh_handler (GHashTable *changes, gpointer user_data)
   /* Next, close if this is a destroy event */
   if (changes) {
     info = gnc_gui_get_entity_events (changes, &cw->customer_guid);
-    if (info && (info->event_mask & GNC_EVENT_DESTROY)) {
+    if (info && (info->event_mask & QOF_EVENT_DESTROY)) {
       gnc_close_gui_component (cw->component_id);
       return;
     }
@@ -391,7 +427,6 @@ gnc_customer_new_window (GNCBook *bookp, GncCustomer *cust)
   CustomerWindow *cw;
   GladeXML *xml;
   GtkWidget *hbox, *edit;
-  GnomeDialog *cwd;
   gnc_commodity *currency;
   GNCPrintAmountInfo print_info;
   
@@ -427,12 +462,8 @@ gnc_customer_new_window (GNCBook *bookp, GncCustomer *cust)
   /* Find the dialog */
   xml = gnc_glade_xml_new ("customer.glade", "Customer Dialog");
   cw->dialog = glade_xml_get_widget (xml, "Customer Dialog");
-  cwd = GNOME_DIALOG (cw->dialog);
 
-  gtk_object_set_data (GTK_OBJECT (cw->dialog), "dialog_info", cw);
-
-  /* default to ok */
-  gnome_dialog_set_default (cwd, 0);
+  g_object_set_data (G_OBJECT (cw->dialog), "dialog_info", cw);
 
   /* Get entry points */
   cw->id_entry = glade_xml_get_widget (xml, "id_entry");
@@ -499,59 +530,16 @@ gnc_customer_new_window (GNCBook *bookp, GncCustomer *cust)
   hbox = glade_xml_get_widget (xml, "credit_box");
   gtk_box_pack_start (GTK_BOX (hbox), edit, TRUE, TRUE, 0);
 
-  /* Setup Dialog for Editing */
-  gnome_dialog_set_default (cwd, 0);
-
-  /* Attach <Enter> to default button */
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->id_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->company_entry));
-
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->name_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->addr1_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->addr2_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->addr3_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->addr4_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->phone_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->fax_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->email_entry));
-
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipname_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipaddr1_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipaddr2_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipaddr3_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipaddr4_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipphone_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipfax_entry));
-  gnome_dialog_editable_enters (cwd, GTK_EDITABLE (cw->shipemail_entry));
-
-  /* Set focus to company name */
-  gtk_widget_grab_focus (cw->company_entry);
-
   /* Setup signals */
-  gnome_dialog_button_connect
-    (cwd, 0, GTK_SIGNAL_FUNC(gnc_customer_window_ok_cb), cw);
-  gnome_dialog_button_connect
-    (cwd, 1, GTK_SIGNAL_FUNC(gnc_customer_window_cancel_cb), cw);
-  gnome_dialog_button_connect
-    (cwd, 2, GTK_SIGNAL_FUNC(gnc_customer_window_help_cb), cw);
-
-  gtk_signal_connect (GTK_OBJECT (cw->dialog), "destroy",
-		      GTK_SIGNAL_FUNC(gnc_customer_window_destroy_cb), cw);
-
-  gtk_signal_connect(GTK_OBJECT (cw->id_entry), "changed",
-		     GTK_SIGNAL_FUNC(gnc_customer_name_changed_cb), cw);
-
-  gtk_signal_connect(GTK_OBJECT (cw->company_entry), "changed",
-		     GTK_SIGNAL_FUNC(gnc_customer_name_changed_cb), cw);
-
-  gtk_signal_connect(GTK_OBJECT (cw->taxtable_check), "toggled",
-		     GTK_SIGNAL_FUNC(gnc_customer_taxtable_check_cb), cw);
+  glade_xml_signal_autoconnect_full( xml,
+                                     gnc_glade_autoconnect_full_func,
+                                     cw);
 
   /* Setup initial values */
   if (cust != NULL) {
+    GtkTextBuffer* text_buffer;
     GncAddress *addr, *shipaddr;
     const char *string;
-    gint pos = 0;
 
     cw->dialog_type = EDIT_CUSTOMER;
     cw->customer_guid = *gncCustomerGetGUID (cust);
@@ -587,9 +575,8 @@ gnc_customer_new_window (GNCBook *bookp, GncCustomer *cust)
                                 gncCustomerGetActive (cust));
 
     string = gncCustomerGetNotes (cust);
-    gtk_editable_delete_text (GTK_EDITABLE (cw->notes_text), 0, -1);
-    gtk_editable_insert_text (GTK_EDITABLE (cw->notes_text), string,
-			      strlen(string), &pos);
+    text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(cw->notes_text));
+    gtk_text_buffer_set_text (text_buffer, string, -1);
 
     cw->component_id =
       gnc_register_gui_component (DIALOG_EDIT_CUSTOMER_CM_CLASS,
@@ -633,7 +620,7 @@ gnc_customer_new_window (GNCBook *bookp, GncCustomer *cust)
 
   gnc_gui_component_watch_entity_type (cw->component_id,
 				       GNC_CUSTOMER_MODULE_NAME,
-				       GNC_EVENT_MODIFY | GNC_EVENT_DESTROY);
+				       QOF_EVENT_MODIFY | QOF_EVENT_DESTROY);
 
   gtk_widget_show_all (cw->dialog);
 
@@ -842,9 +829,10 @@ gnc_customer_search (GncCustomer *start, GNCBook *book)
   sw->book = book;
   sw->q = q;
 
-  return gnc_search_dialog_create (type, params, columns,
-				   q, q2, buttons, NULL,
-				   new_customer_cb, sw, free_userdata_cb);
+  return gnc_search_dialog_create (type, _("Find Customer"),
+				   params, columns, q, q2, buttons, NULL,
+				   new_customer_cb, sw, free_userdata_cb,
+				   GCONF_SECTION_SEARCH, NULL);
 }
 
 GNCSearchWindow *
