@@ -743,7 +743,7 @@
 	(gnc:html-document-add-object!
 	 document
 	 (gnc:make-html-text
-	  (_ "No Valid Invoice Selected"))))
+	  (_ "No valid invoice selected.  Click on the Options button and select the invoice to use."))))
 
     document))
 
