@@ -25,11 +25,11 @@
 #include "config.h"
 
 #include "business-options.h"
+#include "swig-runtime.h"
 
-#include <g-wrap-wct.h>
+#define FUNC_NAME __FUNCTION__
 
-
-#define LOOKUP_OPTION(fcn) { \
+#define LOOKUP_OPTION(fcn) \
   GNCOption *option; \
   SCM getter; \
   SCM value; \
@@ -46,13 +46,9 @@
   value = scm_call_0 (getter); \
   if (value == SCM_BOOL_F) \
     return NULL; \
-  \
-  if (!gw_wcp_p(value)) \
-    scm_misc_error(fcn, "Item is not a gw:wcp.", value); \
-  \
-  return gw_wcp_get_ptr(value); \
-}
-	
+  SWIG_GetModule(NULL); /* Work-around for SWIG bug. */       \
+  if (!SWIG_IsPointer(value))             \
+    scm_misc_error(fcn, "SCM is not a wrapped pointer.", value)
 
 GncTaxTable*
 gnc_option_db_lookup_taxtable_option(GNCOptionDB *odb,
@@ -61,6 +57,7 @@ gnc_option_db_lookup_taxtable_option(GNCOptionDB *odb,
 				     GncTaxTable * default_value)
 {
   LOOKUP_OPTION("gnc_option_db_lookup_taxtable_option");
+  return SWIG_MustGetPtr(value, SWIG_TypeQuery("_p__gncTaxTable"), 1, 0);
 }
 
 GncInvoice*
@@ -70,6 +67,7 @@ gnc_option_db_lookup_invoice_option(GNCOptionDB *odb,
 				    GncInvoice * default_value)
 {
   LOOKUP_OPTION("gnc_option_db_lookup_invoice_option");
+  return SWIG_MustGetPtr(value, SWIG_TypeQuery("_p__gncInvoice"), 1, 0);
 }
 
 GncCustomer*
@@ -79,6 +77,7 @@ gnc_option_db_lookup_customer_option(GNCOptionDB *odb,
 				     GncCustomer * default_value)
 {
   LOOKUP_OPTION("gnc_option_db_lookup_customer_option");
+  return SWIG_MustGetPtr(value, SWIG_TypeQuery("_p__gncCustomer"), 1, 0);
 }
 
 GncVendor*
@@ -88,4 +87,5 @@ gnc_option_db_lookup_vendor_option(GNCOptionDB *odb,
 				   GncVendor * default_value)
 {
   LOOKUP_OPTION("gnc_option_db_lookup_vendor_option");
+  return SWIG_MustGetPtr(value, SWIG_TypeQuery("_p__gncVendor"), 1, 0);
 }
