@@ -56,7 +56,7 @@
 #define GCONF_WARNINGS_PERM	"general/warnings/permanent"
 
 /* Keys used across multiple modules */
-#define DESKTOP_GNOME_INTERFACE "desktop/gnome/interface"
+#define DESKTOP_GNOME_INTERFACE "/desktop/gnome/interface"
 #define KEY_TOOLBAR_STYLE	"toolbar_style"
 #define KEY_SAVE_GEOMETRY	"save_window_geometry"
 #define KEY_LAST_PATH		"last_path"
