@@ -81,6 +81,29 @@ void gnc_utf8_strip_invalid (gchar *str);
  * caller. */
 gchar *gnc_utf8_strip_invalid_strdup (const gchar* str);
 
+typedef gpointer (*GncGMapFunc)(gpointer data, gpointer user_data);
+
+/**
+ * @return Caller-owned GList* of results of apply @a fn to @a list in order.
+ **/
+GList* gnc_g_list_map(GList* list, GncGMapFunc fn, gpointer user_data);
+
+/**
+ * Cut a GList into two parts; the @a cut_point is the beginning of the
+ * new list; @a list may need to be modified, but will be the list
+ * before the @a cut_point.
+ **/
+void gnc_g_list_cut(GList **list, GList *cut_point);
+
+void gnc_scm_log_warn(const gchar *msg);
+void gnc_scm_log_error(const gchar *msg);
+void gnc_scm_log_msg(const gchar *msg);
+void gnc_scm_log_debug(const gchar *msg);
+
+/** Kill a process.  On UNIX send a SIGKILL, on Windows call TerminateProcess.
+ *
+ *  @param pid The process ID. */
+void gnc_gpid_kill(GPid pid);
 
 /** @} */
 
