@@ -46,13 +46,40 @@
 #ifndef GNC_COMMODITY_H
 #define GNC_COMMODITY_H
 
+typedef struct _GncCommodityClass gnc_commodityClass;
+typedef struct _GncCommodityNamespaceClass gnc_commodity_namespaceClass;
+
 #include <glib.h>
 #include "gnc-engine.h"
 
-#define GNC_IS_COMMODITY(obj)  (QOF_CHECK_TYPE((obj), GNC_ID_COMMODITY))
-#define GNC_COMMODITY(obj)     (QOF_CHECK_CAST((obj), GNC_ID_COMMODITY, gnc_commodity))
-#define GNC_IS_COMMODITY_NAMESPACE(obj)  (QOF_CHECK_TYPE((obj), GNC_ID_COMMODITY_NAMESPACE))
-#define GNC_COMMODITY_NAMESPACE(obj)     (QOF_CHECK_CAST((obj), GNC_ID_COMMODITY_NAMESPACE, gnc_commodity_namespace))
+/* --- type macros --- */
+#define GNC_TYPE_COMMODITY            (gnc_commodity_get_type ())
+#define GNC_COMMODITY(o)              \
+     (G_TYPE_CHECK_INSTANCE_CAST ((o), GNC_TYPE_COMMODITY, gnc_commodity))
+#define GNC_COMMODITY_CLASS(k)        \
+     (G_TYPE_CHECK_CLASS_CAST((k), GNC_TYPE_COMMODITY, gnc_commodityClass))
+#define GNC_IS_COMMODITY(o)           \
+     (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNC_TYPE_COMMODITY))
+#define GNC_IS_COMMODITY_CLASS(k)     \
+     (G_TYPE_CHECK_CLASS_TYPE ((k), GNC_TYPE_COMMODITY))
+#define GNC_COMMODITY_GET_CLASS(o)    \
+     (G_TYPE_INSTANCE_GET_CLASS ((o), GNC_TYPE_COMMODITY, gnc_commodityClass))
+GType gnc_commodity_get_type(void);
+
+/* --- type macros --- */
+#define GNC_TYPE_COMMODITY_NAMESPACE            (gnc_commodity_namespace_get_type ())
+#define GNC_COMMODITY_NAMESPACE(o)              \
+     (G_TYPE_CHECK_INSTANCE_CAST ((o), GNC_TYPE_COMMODITY_NAMESPACE, gnc_commodity_namespace))
+#define GNC_COMMODITY_NAMESPACE_CLASS(k)        \
+     (G_TYPE_CHECK_CLASS_CAST((k), GNC_TYPE_COMMODITY_NAMESPACE, gnc_commodity_namespaceClass))
+#define GNC_IS_COMMODITY_NAMESPACE(o)           \
+     (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNC_TYPE_COMMODITY_NAMESPACE))
+#define GNC_IS_COMMODITY_NAMESPACE_CLASS(k)     \
+     (G_TYPE_CHECK_CLASS_TYPE ((k), GNC_TYPE_COMMODITY_NAMESPACE))
+#define GNC_COMMODITY_NAMESPACE_GET_CLASS(o)    \
+     (G_TYPE_INSTANCE_GET_CLASS ((o), GNC_TYPE_COMMODITY_NAMESPACE, gnc_commodity_namespaceClass))
+GType gnc_commodity_namespace_get_type(void);
+
 
 #define GNC_COMMODITY_TABLE "gnc_commodity_table"
 
@@ -78,6 +105,7 @@
 #define GNC_COMMODITY_NS_AMEX   "AMEX"
 #define GNC_COMMODITY_NS_ASX    "ASX"
 
+typedef GList CommodityList;
 
 /** @name Commodity Quote Source functions 
  @{
@@ -807,8 +835,8 @@ guint gnc_commodity_table_get_size(gnc_commodity_table* tbl);
  *  argument was supplied, or the namespace could not be found.
  *
  *  @note It is the callers responsibility to free the list. */
-GList * gnc_commodity_table_get_commodities(const gnc_commodity_table * table,
-					    const char * namespace);
+CommodityList * gnc_commodity_table_get_commodities(
+    const gnc_commodity_table * table, const char * namespace);
 
 /** This function returns a list of commodities for which price quotes
  *  should be retrieved.  It will scan the entire commodity table (or
@@ -827,7 +855,7 @@ GList * gnc_commodity_table_get_commodities(const gnc_commodity_table * table,
  *  quote retrieval.
  *
  *  @note It is the callers responsibility to free the list. */
-GList * gnc_commodity_table_get_quotable_commodities(
+CommodityList * gnc_commodity_table_get_quotable_commodities(
     const gnc_commodity_table * table);
 
 /** Call a function once for each commodity in the commodity table.
