@@ -35,6 +35,24 @@ static QofLogModule log_module = GNC_MOD_PRICE;
 static gboolean add_price(GNCPriceDB *db, GNCPrice *p);
 static gboolean remove_price(GNCPriceDB *db, GNCPrice *p, gboolean cleanup);
 
+/* GObject Initialization */
+QOF_GOBJECT_IMPL(gnc_price, GNCPrice, QOF_TYPE_INSTANCE);
+
+static void
+gnc_price_init(GNCPrice* price)
+{
+}
+
+static void
+gnc_price_dispose_real (GObject *pricep)
+{
+}
+
+static void
+gnc_price_finalize_real(GObject* pricep)
+{
+}
+
 /* ==================================================================== */
 /* GNCPrice functions
  */
@@ -47,17 +65,15 @@ gnc_price_create (QofBook *book)
 
   g_return_val_if_fail (book, NULL);
 
-  p = g_new0(GNCPrice, 1);
+  p = g_object_new(GNC_TYPE_PRICE, NULL);
 
   p->refcount = 1;
-  p->version = 0;
-  p->version_check = 0;
   p->value = gnc_numeric_zero();
   p->type = NULL;
   p->source = NULL;
 
-  qof_instance_init (&p->inst, GNC_ID_PRICE, book);
-  qof_event_gen (&p->inst.entity, QOF_EVENT_CREATE, NULL);
+  qof_instance_init_data (&p->inst, GNC_ID_PRICE, book);
+  qof_event_gen (&p->inst, QOF_EVENT_CREATE, NULL);
 
   return p;
 }
@@ -66,14 +82,13 @@ static void
 gnc_price_destroy (GNCPrice *p)
 {
   ENTER(" ");
-  qof_event_gen (&p->inst.entity, QOF_EVENT_DESTROY, NULL);
+  qof_event_gen (&p->inst, QOF_EVENT_DESTROY, NULL);
 
   if(p->type) CACHE_REMOVE(p->type);
   if(p->source) CACHE_REMOVE(p->source);
 
-  qof_instance_release (&p->inst);
-  memset(p, 0, sizeof(GNCPrice));
-  g_free(p);
+  /* qof_instance_release (&p->inst); */
+  g_object_unref(p);
   LEAVE (" ");
 }
 
@@ -119,14 +134,14 @@ gnc_price_clone (GNCPrice* p, QofBook *book)
   new_p = gnc_price_create(book);
   if(!new_p) { LEAVE (" "); return NULL; }
 
-  new_p->version = p->version;
+  qof_instance_copy_version(new_p, p);
 
   gnc_price_begin_edit(new_p);
   /* never ever clone guid's */
   gnc_price_set_commodity(new_p, gnc_price_get_commodity(p));
   gnc_price_set_time(new_p, gnc_price_get_time(p));
   gnc_price_set_source(new_p, gnc_price_get_source(p));
-  gnc_price_set_type(new_p, gnc_price_get_type(p));
+  gnc_price_set_typestr(new_p, gnc_price_get_typestr(p));
   gnc_price_set_value(new_p, gnc_price_get_value(p));
   gnc_price_set_currency(new_p, gnc_price_get_currency(p));
   gnc_price_commit_edit(new_p);
@@ -139,7 +154,7 @@ gnc_price_clone (GNCPrice* p, QofBook *book)
 void
 gnc_price_begin_edit (GNCPrice *p)
 {
-  QOF_BEGIN_EDIT (&p->inst);
+  qof_begin_edit(&p->inst);
 }
 
 static void commit_err (QofInstance *inst, QofBackendError errcode)
@@ -161,7 +176,7 @@ gnc_price_commit_edit (GNCPrice *p)
 void
 gnc_pricedb_begin_edit (GNCPriceDB *pdb)
 {
-  QOF_BEGIN_EDIT (&pdb->inst);
+  qof_begin_edit(&pdb->inst);
 }
 
 void
@@ -261,7 +276,7 @@ gnc_price_set_source(GNCPrice *p, const char *s)
 }
 
 void
-gnc_price_set_type(GNCPrice *p, const char* type)
+gnc_price_set_typestr(GNCPrice *p, const char* type)
 {
   if(!p) return;
   if(safe_strcmp(p->type, type) != 0)
@@ -290,15 +305,6 @@ gnc_price_set_value(GNCPrice *p, gnc_numeric value)
   }
 }
 
-void
-gnc_price_set_version(GNCPrice *p, gint32 vers)
-{
-  /* begin/end edit is inappropriate here, this is a backend thing only. */
-  if(!p) return;
-  p->version = vers;
-}
-
-
 /* ==================================================================== */
 /* getters */
 
@@ -313,14 +319,14 @@ gnc_price_lookup (const GUID *guid, QofBook *book)
 }
 
 gnc_commodity *
-gnc_price_get_commodity(GNCPrice *p)
+gnc_price_get_commodity(const GNCPrice *p)
 {
   if(!p) return NULL;
   return p->commodity;
 }
 
 Timespec
-gnc_price_get_time(GNCPrice *p)
+gnc_price_get_time(const GNCPrice *p)
 {
   if(!p) {
     Timespec result;
@@ -332,21 +338,21 @@ gnc_price_get_time(GNCPrice *p)
 }
 
 const char *
-gnc_price_get_source(GNCPrice *p)
+gnc_price_get_source(const GNCPrice *p)
 {
   if(!p) return NULL;
   return p->source;
 }
 
 const char *
-gnc_price_get_type(GNCPrice *p)
+gnc_price_get_typestr(const GNCPrice *p)
 {
   if(!p) return NULL;
   return p->type;
 }
 
 gnc_numeric
-gnc_price_get_value(GNCPrice *p)
+gnc_price_get_value(const GNCPrice *p)
 {
   if(!p) {
     PERR("price NULL.\n");
@@ -356,21 +362,14 @@ gnc_price_get_value(GNCPrice *p)
 }
 
 gnc_commodity *
-gnc_price_get_currency(GNCPrice *p)
+gnc_price_get_currency(const GNCPrice *p)
 {
   if(!p) return NULL;
   return p->currency;
 }
 
-gint32
-gnc_price_get_version(GNCPrice *p)
-{
-  if(!p) return 0;
-  return (p->version);
-}
-
 gboolean
-gnc_price_equal (GNCPrice *p1, GNCPrice *p2)
+gnc_price_equal (const GNCPrice *p1, const GNCPrice *p2)
 {
   Timespec ts1;
   Timespec ts2;
@@ -396,8 +395,8 @@ gnc_price_equal (GNCPrice *p1, GNCPrice *p2)
                    gnc_price_get_source (p2)) != 0)
     return FALSE;
 
-  if (safe_strcmp (gnc_price_get_type (p1),
-                   gnc_price_get_type (p2)) != 0)
+  if (safe_strcmp (gnc_price_get_typestr (p1),
+                   gnc_price_get_typestr (p2)) != 0)
     return FALSE;
 
   if (!gnc_numeric_eq (gnc_price_get_value (p1),
@@ -458,7 +457,7 @@ price_list_is_duplicate( gpointer data, gpointer user_data )
 }
 
 gboolean
-gnc_price_list_insert(GList **prices, GNCPrice *p, gboolean check_dupl)
+gnc_price_list_insert(PriceList **prices, GNCPrice *p, gboolean check_dupl)
 {
   GList *result_list;
   PriceListIsDuplStruct* pStruct;
@@ -487,7 +486,7 @@ gnc_price_list_insert(GList **prices, GNCPrice *p, gboolean check_dupl)
 }
 
 gboolean
-gnc_price_list_remove(GList **prices, GNCPrice *p)
+gnc_price_list_remove(PriceList **prices, GNCPrice *p)
 {
   GList *result_list;
   GList *found_element;
@@ -512,14 +511,14 @@ price_list_destroy_helper(gpointer data, gpointer user_data)
 }
 
 void
-gnc_price_list_destroy(GList *prices)
+gnc_price_list_destroy(PriceList *prices)
 {
   g_list_foreach(prices, price_list_destroy_helper, NULL);
   g_list_free(prices);
 }
 
 gboolean
-gnc_price_list_equal(GList *prices1, GList *prices2)
+gnc_price_list_equal(PriceList *prices1, PriceList *prices2)
 {
   GList *n1, *n2;
 
@@ -555,6 +554,24 @@ gnc_price_list_equal(GList *prices1, GList *prices2)
    that the value is expressed in terms of.
  */
 
+/* GObject Initialization */
+QOF_GOBJECT_IMPL(gnc_pricedb, GNCPriceDB, QOF_TYPE_INSTANCE);
+
+static void
+gnc_pricedb_init(GNCPriceDB* pdb)
+{
+}
+
+static void
+gnc_pricedb_dispose_real (GObject *pdbp)
+{
+}
+
+static void
+gnc_pricedb_finalize_real(GObject* pdbp)
+{
+}
+
 static GNCPriceDB *
 gnc_pricedb_create(QofBook * book)
 {
@@ -574,8 +591,8 @@ gnc_pricedb_create(QofBook * book)
     return result;
   }
 
-  result = g_new0(GNCPriceDB, 1);
-  qof_instance_init (&result->inst, GNC_ID_PRICEDB, book);
+  result = g_object_new(GNC_TYPE_PRICEDB, NULL);
+  qof_instance_init_data (&result->inst, GNC_ID_PRICEDB, book);
   qof_collection_mark_clean(col);
 
   /** \todo This leaks result when the collection is destroyed.  When
@@ -631,8 +648,8 @@ gnc_pricedb_destroy(GNCPriceDB *db)
   }
   g_hash_table_destroy (db->commodity_hash);
   db->commodity_hash = NULL;
-  qof_instance_release (&db->inst);
-  g_free(db);
+  /* qof_instance_release (&db->inst); */
+  g_object_unref(db);
 }
 
 void
@@ -777,10 +794,11 @@ add_price(GNCPriceDB *db, GNCPrice *p)
   GHashTable *currency_hash;
 
   if(!db || !p) return FALSE;
-  ENTER ("db=%p, pr=%p dirty=%d do-free=%d",
-         db, p, p->inst.dirty, p->inst.do_free);
+  ENTER ("db=%p, pr=%p dirty=%d destroying=%d",
+         db, p, qof_instance_get_dirty_flag(p),
+         qof_instance_get_destroying(p));
 
-  if (db->inst.book != p->inst.book)
+  if (!qof_instance_books_equal(db, p))
   {
      PERR ("attempted to mix up prices across different books");
 	 LEAVE (" ");
@@ -820,10 +838,11 @@ add_price(GNCPriceDB *db, GNCPrice *p)
   }
   g_hash_table_insert(currency_hash, currency, price_list);
   p->db = db;
-  qof_event_gen (&p->inst.entity, QOF_EVENT_ADD, NULL);
+  qof_event_gen (&p->inst, QOF_EVENT_ADD, NULL);
 
-  LEAVE ("db=%p, pr=%p dirty=%d do-free=%d commodity=%s/%s currency_hash=%p",
-         db, p, p->inst.dirty, p->inst.do_free,
+  LEAVE ("db=%p, pr=%p dirty=%d dextroying=%d commodity=%s/%s currency_hash=%p",
+         db, p, qof_instance_get_dirty_flag(p),
+         qof_instance_get_destroying(p),
          gnc_commodity_get_namespace(p->commodity),
          gnc_commodity_get_mnemonic(p->commodity),
          currency_hash);
@@ -837,8 +856,9 @@ gnc_pricedb_add_price(GNCPriceDB *db, GNCPrice *p)
 {
   if(!db || !p) return FALSE;
 
-  ENTER ("db=%p, pr=%p dirty=%d do-free=%d",
-         db, p, p->inst.dirty, p->inst.do_free);
+  ENTER ("db=%p, pr=%p dirty=%d destroying=%d",
+         db, p, qof_instance_get_dirty_flag(p),
+         qof_instance_get_destroying(p));
 
   if (FALSE == add_price(db, p)) 
   {
@@ -850,8 +870,9 @@ gnc_pricedb_add_price(GNCPriceDB *db, GNCPrice *p)
   qof_instance_set_dirty(&db->inst);
   gnc_pricedb_commit_edit(db);
 
-  LEAVE ("db=%p, pr=%p dirty=%d do-free=%d",
-         db, p, p->inst.dirty, p->inst.do_free);
+  LEAVE ("db=%p, pr=%p dirty=%d destroying=%d",
+         db, p, qof_instance_get_dirty_flag(p),
+         qof_instance_get_destroying(p));
 
   return TRUE;
 }
@@ -869,8 +890,9 @@ remove_price(GNCPriceDB *db, GNCPrice *p, gboolean cleanup)
   GHashTable *currency_hash;
 
   if(!db || !p) return FALSE;
-  ENTER ("db=%p, pr=%p dirty=%d do-free=%d",
-         db, p, p->inst.dirty, p->inst.do_free);
+  ENTER ("db=%p, pr=%p dirty=%d destroying=%d",
+         db, p, qof_instance_get_dirty_flag(p),
+         qof_instance_get_destroying(p));
 
   commodity = gnc_price_get_commodity(p);
   if(!commodity) { LEAVE (" no commodity"); return FALSE; }
@@ -885,7 +907,7 @@ remove_price(GNCPriceDB *db, GNCPrice *p, gboolean cleanup)
   currency_hash = g_hash_table_lookup(db->commodity_hash, commodity);
   if(!currency_hash) { LEAVE (" no currency hash"); return FALSE; }
 
-  qof_event_gen (&p->inst.entity, QOF_EVENT_REMOVE, NULL);
+  qof_event_gen (&p->inst, QOF_EVENT_REMOVE, NULL);
   price_list = g_hash_table_lookup(currency_hash, currency);
   gnc_price_ref(p);
   if(!gnc_price_list_remove(&price_list, p)) {
@@ -923,8 +945,9 @@ gnc_pricedb_remove_price(GNCPriceDB *db, GNCPrice *p)
 {
   gboolean rc;
   if(!db || !p) return FALSE;
-  ENTER ("db=%p, pr=%p dirty=%d do-free=%d",
-         db, p, p->inst.dirty, p->inst.do_free);
+  ENTER ("db=%p, pr=%p dirty=%d destroying=%d",
+         db, p, qof_instance_get_dirty_flag(p),
+         qof_instance_get_destroying(p));
 
   gnc_price_ref(p);
   rc = remove_price (db, p, TRUE);
@@ -934,7 +957,7 @@ gnc_pricedb_remove_price(GNCPriceDB *db, GNCPrice *p)
 
   /* invoke the backend to delete this price */
   gnc_price_begin_edit (p);
-  p->inst.do_free = TRUE;
+  qof_instance_set_destroying(p, TRUE);
   gnc_price_commit_edit (p);
   p->db = NULL;
   gnc_price_unref(p);
@@ -1117,7 +1140,7 @@ lookup_latest(gpointer key, gpointer val, gpointer user_data)
   gnc_price_list_insert(return_list, price_list->data, FALSE);
 }
 
-GList *
+PriceList *
 gnc_pricedb_lookup_latest_any_currency(GNCPriceDB *db,
                                        const gnc_commodity *commodity)
 {
@@ -1212,7 +1235,7 @@ gnc_pricedb_has_prices(GNCPriceDB *db,
 }
 
 
-GList *
+PriceList *
 gnc_pricedb_get_prices(GNCPriceDB *db,
                        const gnc_commodity *commodity,
                        const gnc_commodity *currency)
@@ -1258,7 +1281,7 @@ gnc_pricedb_get_prices(GNCPriceDB *db,
 }
 
 
-GList *
+PriceList *
 gnc_pricedb_lookup_day(GNCPriceDB *db,
                        const gnc_commodity *c,
                        const gnc_commodity *currency,
@@ -1331,7 +1354,7 @@ lookup_day(gpointer key, gpointer val, gpointer user_data)
   }
 }
 
-GList *
+PriceList *
 gnc_pricedb_lookup_day_any_currency(GNCPriceDB *db,
 				    const gnc_commodity *c,
                                     Timespec t)
@@ -1376,7 +1399,7 @@ gnc_pricedb_lookup_day_any_currency(GNCPriceDB *db,
 }
 
 
-GList *
+PriceList *
 gnc_pricedb_lookup_at_time(GNCPriceDB *db,
                            const gnc_commodity *c,
                            const gnc_commodity *currency,
@@ -1446,7 +1469,7 @@ lookup_time(gpointer key, gpointer val, gpointer user_data)
   }
 }
 
-GList *
+PriceList *
 gnc_pricedb_lookup_at_time_any_currency(GNCPriceDB *db,
 					const gnc_commodity *c,
                                         Timespec t)
@@ -1706,7 +1729,7 @@ lookup_latest_before(gpointer key, gpointer val, gpointer user_data)
 }
 
 
-GList *
+PriceList *
 gnc_pricedb_lookup_nearest_in_time_any_currency(GNCPriceDB *db,
                                                 const gnc_commodity *c,
                                                 Timespec t)
@@ -1749,7 +1772,7 @@ gnc_pricedb_lookup_nearest_in_time_any_currency(GNCPriceDB *db,
 }
 
 
-GList *
+PriceList *
 gnc_pricedb_lookup_latest_before_any_currency(GNCPriceDB *db,
 					      gnc_commodity *c,
 					      Timespec t)
@@ -2268,7 +2291,7 @@ gnc_price_print(GNCPrice *p, FILE *f, int indent)
   str = gnc_price_get_source(p);
   str = str ? str : "(null)";
   fprintf(f, "%s  %s\n", istr, str);
-  str = gnc_price_get_type(p);
+  str = gnc_price_get_typestr(p);
   str = str ? str : "(null)";
   fprintf(f, "%s  %s\n", istr, str);
   fprintf(f, "%s  %g\n", istr, gnc_numeric_to_double(gnc_price_get_value(p)));
@@ -2376,7 +2399,7 @@ void_unstable_price_traversal(GNCPriceDB *db,
 }
 
 static void
-price_foreach(QofCollection *col, QofEntityForeachCB cb, gpointer data)
+price_foreach(const QofCollection *col, QofInstanceForeachCB cb, gpointer data)
 {
   GNCPriceDB *db;
 
@@ -2452,7 +2475,7 @@ gnc_pricedb_register (void)
     { PRICE_CURRENCY, GNC_ID_COMMODITY, (QofAccessFunc)gnc_price_get_currency, (QofSetterFunc)gnc_price_set_currency },
     { PRICE_DATE, QOF_TYPE_DATE, (QofAccessFunc)gnc_price_get_time, (QofSetterFunc)gnc_price_set_time },
     { PRICE_SOURCE, QOF_TYPE_STRING, (QofAccessFunc)gnc_price_get_source, (QofSetterFunc)gnc_price_set_source },
-    { PRICE_TYPE, QOF_TYPE_STRING, (QofAccessFunc)gnc_price_get_type, (QofSetterFunc)gnc_price_set_type },
+    { PRICE_TYPE, QOF_TYPE_STRING, (QofAccessFunc)gnc_price_get_typestr, (QofSetterFunc)gnc_price_set_typestr },
     { PRICE_VALUE, QOF_TYPE_NUMERIC, (QofAccessFunc)gnc_price_get_value, (QofSetterFunc)gnc_price_set_value },
     { NULL },
   };
