@@ -25,11 +25,11 @@
 #include "config.h"
 
 #include <gnome.h>
-#ifndef HAVE_GLIB26
-#include "gutils26.h"
-#endif
 #include <glib/gi18n.h>
 #include <math.h>
+#ifdef G_OS_WIN32
+#include <pow.h>
+#endif
 #include <string.h>
 
 #include "Transaction.h"
@@ -54,6 +54,14 @@
 #define DIALOG_EDIT_ACCOUNT_CM_CLASS "dialog-edit-account"
 #define GCONF_SECTION "dialogs/account"
 
+enum account_cols {
+  ACCOUNT_COL_FULLNAME = 0,
+  ACCOUNT_COL_FIELDNAME,
+  ACCOUNT_COL_OLD_VALUE,
+  ACCOUNT_COL_NEW_VALUE,
+  NUM_ACCOUNT_COLS
+};
+
 typedef enum
 {
   NEW_ACCOUNT,
@@ -62,13 +70,13 @@ typedef enum
 
 typedef struct _AccountWindow
 {
+  QofBook *book;
   gboolean modal;
   GtkWidget *dialog;
 
   AccountDialogType dialog_type;
 
   GUID    account;
-  Account *top_level_account; /* owned by the model */
   Account *created_account;
 
   gchar **subaccount_names;
@@ -122,7 +130,7 @@ typedef struct _RenumberDialog
 /** Static Globals *******************************************************/
 static QofLogModule log_module = GNC_MOD_GUI;
 
-static GNCAccountType last_used_account_type = BANK;
+static GNCAccountType last_used_account_type = ACCT_TYPE_BANK;
 
 static GList *ac_destroy_cb_list = NULL;
 
@@ -153,7 +161,7 @@ aw_get_account (AccountWindow *aw)
   if (!aw)
     return NULL;
 
-  return xaccAccountLookup (&aw->account, gnc_get_current_book ());
+  return xaccAccountLookup (&aw->account, aw->book);
 }
 
 static void
@@ -161,7 +169,7 @@ gnc_account_commodity_from_type (AccountWindow * aw, gboolean update)
 {
   dialog_commodity_mode new_mode;
 
-  if ((aw->type == STOCK) || (aw->type == MUTUAL))
+  if ((aw->type == ACCT_TYPE_STOCK) || (aw->type == ACCT_TYPE_MUTUAL))
     new_mode = DIAG_COMM_NON_CURRENCY;
   else
     new_mode = DIAG_COMM_CURRENCY;
@@ -211,7 +219,7 @@ gnc_account_to_ui(AccountWindow *aw)
   } else {
     index = 0;
   }
-  gtk_option_menu_set_history(GTK_OPTION_MENU(aw->account_scu), index);
+  gtk_combo_box_set_active(GTK_COMBO_BOX(aw->account_scu), index);
 
   string = xaccAccountGetCode (account);
   if (string == NULL) string = "";
@@ -238,7 +246,8 @@ gnc_account_to_ui(AccountWindow *aw)
 
 
 static gboolean
-gnc_account_create_transfer_balance (Account *account,
+gnc_account_create_transfer_balance (QofBook *book,
+                                     Account *account,
                                      Account *transfer,
                                      gnc_numeric balance,
                                      time_t date)
@@ -255,7 +264,7 @@ gnc_account_create_transfer_balance (Account *account,
   xaccAccountBeginEdit (account);
   xaccAccountBeginEdit (transfer);
 
-  trans = xaccMallocTransaction (gnc_get_current_book ());
+  trans = xaccMallocTransaction (book);
 
   xaccTransBeginEdit (trans);
 
@@ -263,7 +272,7 @@ gnc_account_create_transfer_balance (Account *account,
   xaccTransSetDateSecs (trans, date);
   xaccTransSetDescription (trans, _("Opening Balance"));
 
-  split = xaccMallocSplit (gnc_get_current_book ());
+  split = xaccMallocSplit (book);
 
   xaccTransAppendSplit (trans, split);
   xaccAccountInsertSplit (account, split);
@@ -273,7 +282,7 @@ gnc_account_create_transfer_balance (Account *account,
 
   balance = gnc_numeric_neg (balance);
 
-  split = xaccMallocSplit (gnc_get_current_book ());
+  split = xaccMallocSplit (book);
 
   xaccTransAppendSplit (trans, split);
   xaccAccountInsertSplit (transfer, split);
@@ -342,7 +351,7 @@ gnc_ui_to_account(AccountWindow *aw)
     old_scu = xaccAccountGetCommoditySCU(account);
   }
 
-  index = gnc_option_menu_get_active(aw->account_scu);
+  index = gtk_combo_box_get_active(GTK_COMBO_BOX(aw->account_scu));
   nonstd = (index != 0);
   if (nonstd != xaccAccountGetNonStdSCU(account))
     xaccAccountSetNonStdSCU(account, nonstd);
@@ -375,18 +384,11 @@ gnc_ui_to_account(AccountWindow *aw)
   xaccAccountSetHidden (account, flag);
 
   parent_account = gnc_tree_view_account_get_selected_account (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree));
-  if (parent_account == aw->top_level_account)
-    parent_account = NULL;
 
-  if (parent_account != NULL)
-  {
-    xaccAccountBeginEdit (parent_account);
-    if (parent_account != xaccAccountGetParentAccount (account))
-      xaccAccountInsertSubAccount (parent_account, account);
-    xaccAccountCommitEdit (parent_account);
-  }
-  else
-    xaccGroupInsertAccount (gnc_get_current_group (), account);
+  if (parent_account == NULL)
+    parent_account = gnc_book_get_root_account(aw->book);
+  if (parent_account != gnc_account_get_parent (account))
+    gnc_account_append_child (parent_account, account);
 
   xaccAccountCommitEdit (account);
 
@@ -409,8 +411,7 @@ gnc_ui_to_account(AccountWindow *aw)
 
   if (use_equity)
   {
-    if (!gnc_account_create_opening_balance (account, balance, date,
-                                             gnc_get_current_book ()))
+    if (!gnc_account_create_opening_balance (account, balance, date, aw->book))
     {
       const char *message = _("Could not create opening balance.");
       gnc_error_dialog(aw->dialog, message);
@@ -426,7 +427,7 @@ gnc_ui_to_account(AccountWindow *aw)
       return;
     }
 
-    gnc_account_create_transfer_balance (account, transfer, balance, date);
+    gnc_account_create_transfer_balance (aw->book, account, transfer, balance, date);
   }
     LEAVE(" ");
 }
@@ -435,14 +436,13 @@ gnc_ui_to_account(AccountWindow *aw)
 static void
 set_children_types (Account *account, GNCAccountType type)
 {
-  AccountGroup *children;
-  GList *iter;
+  GList *children, *iter;
 
-  children = xaccAccountGetChildren (account);
+  children = gnc_account_get_children(account);
   if (children == NULL)
     return;
 
-  for (iter=xaccGroupGetAccountList (children); iter; iter=iter->next) {
+  for (iter=children; iter; iter=iter->next) {
     account = iter->data;
     if (type == xaccAccountGetType(account))
       continue;
@@ -456,6 +456,7 @@ set_children_types (Account *account, GNCAccountType type)
 
     set_children_types (account, type);
   }
+  g_list_free(children);
 }
 
 static void
@@ -465,6 +466,9 @@ make_children_compatible (AccountWindow *aw)
 
   g_return_if_fail (aw);
 
+  if (aw->dialog_type == NEW_ACCOUNT)
+      return;
+
   account = aw_get_account (aw);
   g_return_if_fail (account);
 
@@ -497,7 +501,7 @@ gnc_finish_ok (AccountWindow *aw)
     gnc_suspend_gui_refresh ();
 
     parent = aw_get_account (aw);
-    account = xaccMallocAccount (gnc_get_current_book ());
+    account = xaccMallocAccount (aw->book);
     aw->account = *xaccAccountGetGUID (account);
     aw->type = xaccAccountGetType (parent);
 
@@ -513,8 +517,8 @@ gnc_finish_ok (AccountWindow *aw)
                                       commodity);
     gnc_account_commodity_from_type (aw, FALSE);
 
-    gnc_tree_view_account_set_selected_account
-      (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree), parent);
+    gnc_tree_view_account_set_selected_account (
+        GNC_TREE_VIEW_ACCOUNT (aw->parent_tree), parent);
 
     gnc_resume_gui_refresh ();
     LEAVE("1");
@@ -543,8 +547,7 @@ add_children_to_expander (GObject *object, GParamSpec *param_spec, gpointer data
   if (gtk_expander_get_expanded (expander) &&
       !gtk_bin_get_child (GTK_BIN (expander))) {
 
-    view = gnc_tree_view_account_new_with_group (
-      xaccAccountGetChildren (account), FALSE);
+    view = gnc_tree_view_account_new_with_root (account, FALSE);
 
     scrolled_window = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
@@ -565,7 +568,6 @@ static gboolean
 verify_children_compatible (AccountWindow *aw)
 {
   Account *account;
-  AccountGroup *children;
   GtkWidget *dialog, *vbox, *hbox, *label, *expander;
   gchar *str;
   gboolean result;
@@ -580,9 +582,7 @@ verify_children_compatible (AccountWindow *aw)
   if (xaccAccountTypesCompatible (xaccAccountGetType (account), aw->type))
     return TRUE;
 
-  children = xaccAccountGetChildren (account);
-  if (!children ||
-      !xaccGroupGetNumAccounts (children))
+  if (gnc_account_n_children(account) == 0)
     return TRUE;
 
   dialog = gtk_dialog_new_with_buttons ("",
@@ -676,7 +676,7 @@ gnc_filter_parent_accounts (Account *account, gpointer data)
   if (aw_account == NULL)
     return FALSE;
 
-  if (account == aw->top_level_account)
+  if (gnc_account_is_root(account))
     return TRUE;
 
   if (account == aw_account)
@@ -692,14 +692,13 @@ gnc_filter_parent_accounts (Account *account, gpointer data)
 static gboolean
 gnc_common_ok (AccountWindow *aw)
 {
-  Account *account, *parent;
-  AccountGroup *group;
+  Account *root, *account, *parent;
   gnc_commodity * commodity;
   gchar *fullname, *fullname_parent;
   const gchar *name, *separator;
 
   ENTER("aw %p", aw);
-  group = gnc_get_current_group ();
+  root = gnc_book_get_root_account (aw->book);
 
   separator = gnc_get_account_separator_string();
 
@@ -716,12 +715,12 @@ gnc_common_ok (AccountWindow *aw)
   parent = gnc_tree_view_account_get_selected_account
     (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree));
   if (parent == NULL) {
-    account = xaccGetAccountFromFullName(group, name);
+    account = gnc_account_lookup_by_full_name(root, name);
   } else {
     fullname_parent = xaccAccountGetFullName(parent);
     fullname = g_strconcat(fullname_parent, separator, name, NULL);
 
-    account = xaccGetAccountFromFullName(group, fullname);
+    account = gnc_account_lookup_by_full_name(root, fullname);
 
     g_free(fullname_parent);
     g_free(fullname);
@@ -743,7 +742,7 @@ gnc_common_ok (AccountWindow *aw)
   }
 
   /* check for valid type */
-  if (aw->type == BAD_TYPE) {
+  if (aw->type == ACCT_TYPE_INVALID) {
     const char *message = _("You must select an account type.");
     gnc_error_dialog(aw->dialog, message);
     LEAVE("invalid type");
@@ -751,8 +750,7 @@ gnc_common_ok (AccountWindow *aw)
   }
 
   /* check whether the types of child and parent are compatible */
-  if (parent != aw->top_level_account &&
-      !xaccAccountTypesCompatible (aw->type, xaccAccountGetType (parent))) {
+  if (!xaccAccountTypesCompatible (aw->type, xaccAccountGetType (parent))) {
     const char *message = _("The selected account type is incompatible with "
                             "the one of the selected parent.");
     gnc_error_dialog(aw->dialog, message);
@@ -798,7 +796,7 @@ gnc_edit_account_ok(AccountWindow *aw)
   }
 
   gnc_finish_ok (aw);
-    LEAVE(" ");
+  LEAVE(" ");
 }
 
 
@@ -937,8 +935,6 @@ gnc_account_window_destroy_cb (GtkObject *object, gpointer data)
 
   gnc_unregister_gui_component (aw->component_id);
 
-  aw->top_level_account = NULL;
-
   gnc_resume_gui_refresh ();
 
   if (aw->subaccount_names) {
@@ -968,11 +964,11 @@ gnc_account_parent_changed_cb (GtkTreeSelection *selection, gpointer data)
   if (!parent_account)
     return;
 
-  if (parent_account == aw->top_level_account) {
+  if (gnc_account_is_root(parent_account)) {
     types = aw->valid_types;
   } else {
     types = aw->valid_types &
-      xaccAccountTypesCompatibleWith (xaccAccountGetType (parent_account));
+      xaccParentAccountTypesCompatibleWith (xaccAccountGetType (parent_account));
   }
 
   type_model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->type_view));
@@ -987,7 +983,7 @@ gnc_account_parent_changed_cb (GtkTreeSelection *selection, gpointer data)
   }
   else if ((types & (1 << aw->type)) == 0) {
     /* our type is invalid now */
-    aw->type = BAD_TYPE;
+    aw->type = ACCT_TYPE_INVALID;
   }
   else {
     /* no type change, but maybe list of valid types changed */
@@ -1002,6 +998,8 @@ gnc_account_parent_changed_cb (GtkTreeSelection *selection, gpointer data)
     type_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->type_view));
     gnc_tree_model_account_types_set_selection(type_selection, 1 << aw->type);
   }
+
+  gnc_account_window_set_name(aw);
 }
 
 static void
@@ -1016,18 +1014,18 @@ gnc_account_type_changed_cb (GtkTreeSelection *selection, gpointer data)
   sensitive = FALSE;
 
   type_id = gnc_tree_model_account_types_get_selection_single(selection);
-  if (type_id == NO_TYPE) {
-    aw->type = BAD_TYPE;
+  if (type_id == ACCT_TYPE_NONE) {
+    aw->type = ACCT_TYPE_INVALID;
   } else {
     aw->type = type_id;
     aw->preferred_account_type = type_id;
 
     gnc_account_commodity_from_type (aw, TRUE);
 
-    sensitive = (aw->type != EQUITY &&
-		 aw->type != CURRENCY &&
-		 aw->type != STOCK &&
-		 aw->type != MUTUAL);
+    sensitive = (aw->type != ACCT_TYPE_EQUITY &&
+		 aw->type != ACCT_TYPE_CURRENCY &&
+		 aw->type != ACCT_TYPE_STOCK &&
+		 aw->type != ACCT_TYPE_MUTUAL);
   }
 
   gtk_widget_set_sensitive (aw->opening_balance_page, sensitive);
@@ -1064,7 +1062,7 @@ gnc_account_type_view_create (AccountWindow *aw)
     /* choose first valid account type */
     int i;
     aw->preferred_account_type = aw->type;
-    aw->type = BAD_TYPE;
+    aw->type = ACCT_TYPE_INVALID;
     for (i=0; i<32; i++)
       if ((aw->valid_types & (1 << i)) != 0) {
         aw->type = i;
@@ -1221,19 +1219,15 @@ gnc_account_window_create(AccountWindow *aw)
                     G_CALLBACK (commodity_changed_cb), aw);
 
   aw->account_scu = glade_xml_get_widget (xml, "account_scu");
-  gnc_option_menu_init(aw->account_scu);
 
   box = glade_xml_get_widget (xml, "parent_scroll");
 
-  //  group = gnc_book_get_group (gnc_get_current_book ());
   aw->parent_tree = gnc_tree_view_account_new(TRUE);
   gtk_container_add(GTK_CONTAINER(box), GTK_WIDGET(aw->parent_tree));
   gtk_widget_show(GTK_WIDGET(aw->parent_tree));
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->parent_tree));
   g_signal_connect (G_OBJECT (selection), "changed",
                     G_CALLBACK (gnc_account_parent_changed_cb), aw);
-  aw->top_level_account =
-    gnc_tree_view_account_get_top_level (GNC_TREE_VIEW_ACCOUNT(aw->parent_tree));
 
   aw->tax_related_button = glade_xml_get_widget (xml, "tax_related_button");
   aw->placeholder_button = glade_xml_get_widget (xml, "placeholder_button");
@@ -1271,7 +1265,7 @@ gnc_account_window_create(AccountWindow *aw)
   gtk_widget_show (GTK_WIDGET(aw->transfer_tree));
 
   label = glade_xml_get_widget (xml, "parent_label");
-  gtk_label_set_mnemonic_widget (GTK_LABEL(label), aw->transfer_tree);
+  gtk_label_set_mnemonic_widget (GTK_LABEL(label), GTK_WIDGET(aw->parent_tree));
 
   /* This goes at the end so the select callback has good data. */
   aw->type_view = glade_xml_get_widget (xml, "type_view");
@@ -1295,13 +1289,9 @@ get_ui_fullname (AccountWindow *aw)
   if (!name || *name == '\0')
     name = _("<No name>");
 
-  parent_account = NULL;
-
   parent_account = gnc_tree_view_account_get_selected_account (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree));
-  if (parent_account == aw->top_level_account)
-    parent_account = NULL;
 
-  if (parent_account)
+  if (parent_account && !gnc_account_is_root(parent_account))
   {
     char *parent_name;
     const gchar *separator;
@@ -1414,7 +1404,8 @@ refresh_handler (GHashTable *changes, gpointer user_data)
 
 
 static AccountWindow *
-gnc_ui_new_account_window_internal (Account *base_account,
+gnc_ui_new_account_window_internal (QofBook *book,
+                                    Account *base_account,
                                     gchar **subaccount_names,
 				    GList *valid_types,
 				    gnc_commodity * default_commodity,
@@ -1425,8 +1416,11 @@ gnc_ui_new_account_window_internal (Account *base_account,
   Account *account;
   GList *list;
 
+  g_return_val_if_fail(book, NULL);
+
   aw = g_new0 (AccountWindow, 1);
 
+  aw->book = book;
   aw->modal = modal;
   aw->dialog_type = NEW_ACCOUNT;
 
@@ -1434,7 +1428,7 @@ gnc_ui_new_account_window_internal (Account *base_account,
   for (list = valid_types; list; list = list->next)
     aw->valid_types |= (1 << GPOINTER_TO_INT (list->data));
 
-  account = xaccMallocAccount (gnc_get_current_book ());
+  account = xaccMallocAccount (book);
   aw->account = *xaccAccountGetGUID (account);
 
   if (base_account) {
@@ -1461,7 +1455,7 @@ gnc_ui_new_account_window_internal (Account *base_account,
 
   if (default_commodity != NULL) {
     commodity = default_commodity;
-  } else if ((aw->type != STOCK) && (aw->type != MUTUAL)) {
+  } else if ((aw->type != ACCT_TYPE_STOCK) && (aw->type != ACCT_TYPE_MUTUAL)) {
     commodity = parent_commodity;
   } else {
     commodity = NULL;
@@ -1470,8 +1464,9 @@ gnc_ui_new_account_window_internal (Account *base_account,
                                     commodity);
   gnc_account_commodity_from_type (aw, FALSE);
 
-  if (base_account == NULL)
-    base_account = aw->top_level_account;
+  if (base_account == NULL) {
+    base_account = gnc_book_get_root_account(book);
+  }
 
   gtk_tree_view_collapse_all (aw->parent_tree);
   gnc_tree_view_account_set_selected_account (
@@ -1497,21 +1492,20 @@ gnc_ui_new_account_window_internal (Account *base_account,
 
 
 static gchar **
-gnc_split_account_name (const char *in_name, Account **base_account)
+gnc_split_account_name (QofBook *book, const char *in_name, Account **base_account)
 {
-  AccountGroup *group;
-  Account *account;
+  Account *root, *account;
   gchar **names, **ptr, **out_names;
   GList *list, *node;
 
-  group = gnc_get_current_group ();
+  root = gnc_book_get_root_account (book);
+  list = gnc_account_get_children(root);
   names = g_strsplit(in_name, gnc_get_account_separator_string(), -1);
 
   for (ptr = names; *ptr; ptr++) {
     /* Stop if there are no children at the current level. */
-    if (group == NULL)
+    if (list == NULL)
       break;
-    list = xaccGroupGetAccountList (group);
 
     /* Look for the first name in the children. */
     for (node = list; node; node = g_list_next(node)) {
@@ -1528,11 +1522,14 @@ gnc_split_account_name (const char *in_name, Account **base_account)
     if (node == NULL)
       break;
 
-    group = xaccAccountGetChildren (account);
+    g_list_free(list);
+    list = gnc_account_get_children (account);
   }
 
   out_names = g_strdupv(ptr);
   g_strfreev(names);
+  if (list)
+    g_list_free(list);
   return out_names;
 }
 
@@ -1560,6 +1557,7 @@ gnc_ui_new_accounts_from_name_with_defaults (const char *name,
                                              gnc_commodity * default_commodity,
                                              Account * parent)
 {
+  QofBook *book;
   AccountWindow *aw;
   Account *base_account = NULL;
   Account *created_account = NULL;
@@ -1569,19 +1567,20 @@ gnc_ui_new_accounts_from_name_with_defaults (const char *name,
 
   ENTER("name %s, valid %p, commodity %p, account %p",
 	name, valid_types, default_commodity, parent);
+  book = gnc_get_current_book();
   if (!name || *name == '\0')
   {
     subaccount_names = NULL;
     base_account = NULL;
   }
   else
-    subaccount_names = gnc_split_account_name (name, &base_account);
+    subaccount_names = gnc_split_account_name (book, name, &base_account);
 
   if (parent != NULL)
     {
       base_account=parent;
     }
-  aw = gnc_ui_new_account_window_internal (base_account, subaccount_names, 
+  aw = gnc_ui_new_account_window_internal (book, base_account, subaccount_names,
 					   valid_types, default_commodity,
 					   TRUE);
 
@@ -1652,6 +1651,7 @@ gnc_ui_edit_account_window(Account *account)
 
   aw = g_new0 (AccountWindow, 1);
 
+  aw->book = gnc_account_get_book(account);
   aw->modal = FALSE;
   aw->dialog_type = EDIT_ACCOUNT;
   aw->account = *xaccAccountGetGUID (account);
@@ -1668,9 +1668,9 @@ gnc_ui_edit_account_window(Account *account)
   gtk_widget_show_all (aw->dialog);
   gtk_widget_hide (aw->opening_balance_page);
 
-  parent = xaccAccountGetParentAccount (account);
+  parent = gnc_account_get_parent (account);
   if (parent == NULL)
-    parent = aw->top_level_account;
+    parent = account;		/* must be at the root */
 
   gtk_tree_view_collapse_all (aw->parent_tree);
   gnc_tree_view_account_set_selected_account (
@@ -1696,33 +1696,24 @@ gnc_ui_edit_account_window(Account *account)
 /*
  * opens up a window to create a new account
  * 
- * Args:   group - not used
+ * Args:    book - containing book for the new account
+ *        parent - The initial parent for the new account (optional)
  */
 void
-gnc_ui_new_account_window (AccountGroup *this_is_not_used) 
+gnc_ui_new_account_window(QofBook *book, Account *parent)
 {
-  /* FIXME get_current_account went away. */
-  gnc_ui_new_account_window_internal (NULL, NULL, NULL, NULL, FALSE);
-}
+  g_return_if_fail(book != NULL);
+  if (parent && book)
+    g_return_if_fail(gnc_account_get_book(parent) == book);
 
-/*
- * opens up a window to create a new account
- * 
- * Args:   group - not used
- *        parent - The initial parent for the new account
- */
-void
-gnc_ui_new_account_window_with_default(AccountGroup *this_is_not_used,
-                                       Account * parent)
-{
-  gnc_ui_new_account_window_internal (parent, NULL, NULL, NULL, FALSE);
+  gnc_ui_new_account_window_internal (book, parent, NULL, NULL, NULL, FALSE);
 }
 
 void
-gnc_ui_new_account_with_types( AccountGroup *unused,
+gnc_ui_new_account_with_types( QofBook *book,
                                GList *valid_types )
 {
-  gnc_ui_new_account_window_internal( NULL, NULL, valid_types, NULL, FALSE );
+  gnc_ui_new_account_window_internal( book, NULL, NULL, valid_types, NULL, FALSE );
 }
 
 /************************************************************
@@ -1730,7 +1721,7 @@ gnc_ui_new_account_with_types( AccountGroup *unused,
  ************************************************************/
 
 /*
- * register a callback that get's called when the account has changed
+ * register a callback that gets called when the account has changed
  * so significantly that you need to destroy yourself.  In particular
  * this is used by the ledger display to destroy ledgers when the
  * account type has changed.
@@ -1791,7 +1782,6 @@ gnc_account_renumber_response_cb (GtkDialog *dialog,
 			       gint response,
 			       RenumberDialog *data)
 {
-  AccountGroup *group;
   GList *children, *tmp;
   gchar *str;
   gchar *prefix;
@@ -1799,8 +1789,7 @@ gnc_account_renumber_response_cb (GtkDialog *dialog,
 
   if (response == GTK_RESPONSE_OK) {
     gtk_widget_hide(data->dialog);
-    group = xaccAccountGetChildren(data->parent);
-    children = xaccGroupGetAccountListSorted(group);
+    children = gnc_account_get_children(data->parent);
     prefix = gtk_editable_get_chars(GTK_EDITABLE(data->prefix), 0, -1);
     interval =
       gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(data->interval));
@@ -1813,6 +1802,7 @@ gnc_account_renumber_response_cb (GtkDialog *dialog,
       g_free(str);
     }
     gnc_unset_busy_cursor (NULL);
+    g_list_free(children);
   }
 
   gtk_widget_destroy(data->dialog);
@@ -1824,14 +1814,12 @@ gnc_account_renumber_create_dialog (GtkWidget *window, Account *account)
 {
   RenumberDialog *data;
   GladeXML *xml;
-  AccountGroup *children;
   GtkWidget *widget;
   gchar *string;
 
   data = g_new(RenumberDialog, 1);
   data->parent = account;
-  children = xaccAccountGetChildren(account);
-  data->num_children = xaccGroupGetNumAccounts(children);
+  data->num_children = gnc_account_n_children(account);
 
   xml = gnc_glade_xml_new ("account.glade", "Renumber Accounts");
   data->dialog = glade_xml_get_widget (xml, "Renumber Accounts");
