@@ -113,8 +113,10 @@ gboolean gnc_handle_date_accelerator (GdkEventKey *event,
  * place. Stick to gtk_clist_append, or use gnc_clist_set_check
  * after you have built the list. This only applies to unrealized
  * widgets. */
+#ifdef __GTK_CLIST_H__
 void gnc_clist_set_check (GtkCList *list, int row, int col, 
 			  gboolean checked);
+#endif
 
 GladeXML * gnc_glade_xml_new (const char *filename, const char *root);
 GtkWidget * gnc_glade_lookup_widget (GtkWidget *widget, const char *name);
@@ -150,11 +152,4 @@ void gnc_gtk_dialog_add_button (GtkWidget *dialog,
 gint
 gnc_dialog_run(GtkDialog *dialog, const gchar *gconf_key);
 
-#ifndef HAVE_GTK26
-void
-gtk_message_dialog_format_secondary_text(GtkMessageDialog *dialog,
-					 const gchar *message_format,
-					 ...) G_GNUC_PRINTF (2, 3);
-#endif
-
 #endif
