@@ -34,6 +34,7 @@
 
 #include <gnome.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <sys/types.h>
@@ -41,7 +42,7 @@
 #include "dialog-utils.h"
 #include "druid-gconf-setup.h"
 #include "druid-utils.h"
-#include "gnc-dir.h"
+#include "gnc-path.h"
 #include "gnc-gconf-utils.h"
 #include "gnc-gui-query.h"
 #include "gnc-gnome-utils.h"
@@ -113,6 +114,7 @@ druid_gconf_update_path (GError **error)
   gchar *contents, **lines, *line;
   gboolean found_user_dir = FALSE;
   FILE *output;
+  gchar *gconfdir;
 
   data_filename = g_build_filename(g_get_home_dir(), ".gconf", (char *)NULL);
   path_filename = g_build_filename(g_get_home_dir(), ".gconf.path", (char *)NULL);
@@ -137,7 +139,7 @@ druid_gconf_update_path (GError **error)
     g_strfreev(lines);
   }
 
-  output = fopen(path_filename, "a");
+  output = g_fopen(path_filename, "a");
   if (output == NULL) {
     *error = g_error_new (G_FILE_ERROR,
 			  g_file_error_from_errno(errno),
@@ -151,7 +153,9 @@ druid_gconf_update_path (GError **error)
   fprintf(output, "\n######## The following lines were added by GnuCash. ########\n");
   if (!found_user_dir)
     fprintf(output, PATH_STRING1);
-  fprintf(output, PATH_STRING2, GNC_GCONF_DIR);
+  gconfdir = gnc_path_get_gconfdir (TRUE);
+  fprintf(output, PATH_STRING2, gconfdir);
+  g_free (gconfdir);
   fprintf(output,   "############## End of lines added by GnuCash. ##############\n");
   if (fclose(output) != 0)  {
     *error = g_error_new (G_FILE_ERROR,
@@ -284,11 +288,13 @@ druid_gconf_update_page_prepare (GnomeDruidPage *druidpage,
   GtkTextBuffer *textbuffer;
   GtkWidget *textview;
   gchar *msg;
+  gchar *gconfdir = gnc_path_get_gconfdir (TRUE);
 
   textview = gnc_glade_lookup_widget(GTK_WIDGET(druidpage), "update_text");
   textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
-  msg = g_strdup_printf(PATH_STRING1 PATH_STRING2, GNC_GCONF_DIR);
+  msg = g_strdup_printf(PATH_STRING1 PATH_STRING2, gconfdir);
   gtk_text_buffer_set_text(textbuffer, msg, -1);
+  g_free (gconfdir);
 }
 
 
@@ -609,6 +615,25 @@ druid_gconf_install_check_schemas (void)
     return;
   }
 
+#ifdef G_OS_WIN32
+  {
+    /* automatically update the search path on windows */
+    GError *error = NULL;
+    if (!druid_gconf_update_path (&error)) {
+      gnc_error_dialog (NULL, error->message);
+      g_error_free (error);
+      exit(42);
+    } else {
+      if (!g_spawn_command_line_sync("gconftool-2 --shutdown", NULL, NULL,
+				     NULL, &error)) {
+	gnc_warning_dialog(NULL, error->message);
+	g_error_free(error);
+      }
+      return;
+    }
+  }
+#endif /* G_OS_WIN32 */
+
   xml = gnc_glade_xml_new ("druid-gconf-setup.glade", "GConf Query");
   dialog = glade_xml_get_widget (xml, "GConf Query");
   do {
