@@ -127,7 +127,7 @@ price_to_gui (PriceEditDialog *pedit_dialog)
     currency = gnc_price_get_currency (pedit_dialog->price);
     date = gnc_price_get_time (pedit_dialog->price);
     source = gnc_price_get_source (pedit_dialog->price);
-    type = gnc_price_get_type (pedit_dialog->price);
+    type = gnc_price_get_typestr (pedit_dialog->price);
     value = gnc_price_get_value (pedit_dialog->price);
   }
   else
@@ -196,7 +196,7 @@ gui_to_price (PriceEditDialog *pedit_dialog)
   gnc_price_set_commodity (pedit_dialog->price, commodity);
   gnc_price_set_currency (pedit_dialog->price, currency);
   gnc_price_set_time (pedit_dialog->price, date);
-  gnc_price_set_type (pedit_dialog->price, type);
+  gnc_price_set_typestr (pedit_dialog->price, type);
   gnc_price_set_value (pedit_dialog->price, value);
   gnc_price_commit_edit (pedit_dialog->price);
 
