@@ -1088,7 +1088,7 @@ read_one_check_directory(PrintCheckDialog * pcd, GtkListStore *store,
 		  * is the filename of that format; %3$s the type of
 		  * the other check format; and %4$s the filename of
 		  * that other format. */
-                 _("The guids in the %s check format file '%s' and "
+                 _("The GUIDs in the %s check format file '%s' and "
                    "the %s check format file '%s' match."),
                  existing->group, existing->filename,
                  format->group, format->filename);
@@ -1362,7 +1362,7 @@ draw_text(GncPrintContext * context, const gchar * text, check_item_t * data,
     }
     pango_layout_set_alignment(layout,
                                data->w ? data->align : PANGO_ALIGN_LEFT);
-    pango_layout_set_width(layout, data->w ? data->w * PANGO_SCALE : -1);
+    pango_layout_set_width(layout, -1);
     if (gnc_gconf_get_bool(GCONF_SECTION, KEY_BLOCKING_CHARS, NULL)) {
         new_text = g_strdup_printf("***%s***", text);
         pango_layout_set_text(layout, new_text, -1);
