@@ -173,7 +173,7 @@ static void gnc_sxed_update_cal(GncSxEditorDialog *sxed);
 
 static void gnc_sxed_reg_check_close(GncSxEditorDialog *sxed);
 
-static gint sxed_close_event( GtkDialog *dlg, gpointer ud );
+static gboolean sxed_delete_event( GtkWidget *widget, GdkEvent *event, gpointer ud );
 
 static gboolean sxed_confirmed_cancel( GncSxEditorDialog *sxed );
 
@@ -1036,8 +1036,8 @@ scheduledxaction_editor_dialog_destroy(GtkObject *object, gpointer data)
 }
 
 static
-gint
-sxed_close_event( GtkDialog *dlg, gpointer ud )
+gboolean
+sxed_delete_event( GtkWidget *widget, GdkEvent *event, gpointer ud )
 {
     GncSxEditorDialog *sxed = (GncSxEditorDialog*)ud;
 
@@ -1173,8 +1173,8 @@ gnc_ui_scheduled_xaction_editor_dialog_create(SchedXaction *sx,
                                 sxed_close_handler,
                                 sxed );
 
-    g_signal_connect( sxed->dialog, "close",
-                      G_CALLBACK(sxed_close_event), sxed );
+    g_signal_connect( sxed->dialog, "delete_event",
+                      G_CALLBACK(sxed_delete_event), sxed );
     g_signal_connect( sxed->dialog, "destroy",
                       G_CALLBACK(scheduledxaction_editor_dialog_destroy),
                       sxed );
@@ -1223,6 +1223,9 @@ gnc_ui_scheduled_xaction_editor_dialog_create(SchedXaction *sx,
     gtk_widget_queue_resize( GTK_WIDGET( sxed->example_cal ) );
     gnc_ledger_display_refresh( sxed->ledger );
 
+    /* Move keyboard focus to the name entry */
+    gtk_widget_grab_focus(GTK_WIDGET(sxed->nameEntry));
+
     return sxed;
 }
 
