@@ -5,7 +5,7 @@
  * Copyright (C) 1998 Rob Browning <rlb@cs.utexas.edu>              *
  * Copyright (C) 1999-2000 Dave Peticolas <dave@krondo.com>         *
  * Copyright (C) 2001 Gnumatic, Inc.                                *
- * Copyright (C) 2002 Joshua Sled <jsled@asynchronous.org>          *
+ * Copyright (C) 2002,2006 Joshua Sled <jsled@asynchronous.org>     *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -37,7 +37,7 @@
 #include "QueryNew.h"
 #include "SX-book.h"
 #include "dialog-account.h"
-#include "dialog-scheduledxaction.h"
+#include "dialog-sx-editor.h"
 #include "dialog-sx-from-trans.h"
 #include "gnc-component-manager.h"
 #include "gnc-date-edit.h"
@@ -483,7 +483,7 @@ account_latest_price (Account *account)
   commodity = xaccAccountGetCommodity (account);
   currency = gnc_default_currency ();
 
-  book = xaccAccountGetBook (account);
+  book = gnc_account_get_book (account);
   pdb = gnc_book_get_pricedb (book);
 
   return gnc_pricedb_lookup_latest (pdb, commodity, currency);
@@ -501,7 +501,7 @@ account_latest_price_any_currency (Account *account)
   if (!account) return NULL;
   commodity = xaccAccountGetCommodity (account);
 
-  book = xaccAccountGetBook (account);
+  book = gnc_account_get_book (account);
   pdb = gnc_book_get_pricedb (book);
 
   price_list = gnc_pricedb_lookup_latest_any_currency (pdb, commodity);
@@ -531,13 +531,12 @@ gsr_redraw_all_cb (GnucashRegister *g_reg, gpointer data)
     return;
 
   leader = gnc_ledger_display_leader( gsr->ledger );
-  euro = gnc_gconf_get_bool(GCONF_GENERAL, KEY_ENABLE_EURO, NULL);
 
   commodity = xaccAccountGetCommodity( leader );
 
   /* no EURO converson, if account is already EURO or no EURO currency */
   if (commodity != NULL)
-    euro = (euro && gnc_is_euro_currency( commodity ) && 
+    euro = (gnc_is_euro_currency( commodity ) &&
             (strncasecmp(gnc_commodity_get_mnemonic(commodity), "EUR", 3)));
   else
     euro = FALSE;
@@ -1227,7 +1226,7 @@ gsr_default_schedule_handler( GNCSplitReg *gsr, gpointer data )
         GList *sxElts;
         
         /* Get the correct SX */
-        for ( sxElts = gnc_book_get_schedxactions( gnc_get_current_book() );
+        for ( sxElts = gnc_book_get_schedxactions(gnc_get_current_book())->sx_list;
               (!theSX) && sxElts;
               sxElts = sxElts->next ) {
           SchedXaction *sx = (SchedXaction*)sxElts->data;
@@ -1237,8 +1236,7 @@ gsr_default_schedule_handler( GNCSplitReg *gsr, gpointer data )
         }
 
         if ( theSX ) {
-          SchedXactionDialog *sxd = gnc_ui_scheduled_xaction_dialog_create();
-          gnc_ui_scheduled_xaction_editor_dialog_create( sxd, theSX, FALSE );
+          gnc_ui_scheduled_xaction_editor_dialog_create(theSX, FALSE);
           return;
         }
       }
