@@ -198,6 +198,13 @@ gnc_ui_qif_import_druid_destroy (QIFImportWindow * window)
   g_free(window);
 }
 
+
+/********************************************************************\
+ * get_next_druid_page
+ *
+ * Determine which page should be shown after the current page.
+\********************************************************************/
+
 static GtkWidget * 
 get_next_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
 {
@@ -205,10 +212,11 @@ get_next_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
   GList     * next;
   int       where = 0;
   
+  /* Figure out which stage of the druid we're in. */
   if((current = g_list_find(wind->pre_comm_pages, page)) == NULL) {
     if((current = g_list_find(wind->commodity_pages, page)) == NULL) {
       if((current = g_list_find(wind->post_comm_pages, page)) == NULL) {
-        /* where are we? */
+        /* Where are we? */
         printf("QIF import: I'm lost!\n");
         return FALSE;
       }
@@ -225,9 +233,10 @@ get_next_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
   }
   
   next = current->next;
-  while(!next ||
-        (!wind->show_doc_pages &&
-         g_list_find(wind->doc_pages, next->data))) {
+  while (!next ||
+         (!wind->show_doc_pages && g_list_find(wind->doc_pages, next->data)) ||
+         (wind->new_stocks == SCM_BOOL_F &&
+          GNOME_DRUID_PAGE(next->data) == get_named_page(wind, "commodity_doc_page"))) {
     if(next && next->next) {
       next = next->next;
     }
@@ -254,6 +263,13 @@ get_next_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
   else return NULL;
 }
 
+
+/********************************************************************\
+ * get_prev_druid_page
+ *
+ * Determine which page was shown before the current page.
+\********************************************************************/
+
 static GtkWidget * 
 get_prev_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
 {
@@ -261,10 +277,11 @@ get_prev_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
   GList     * prev;
   int       where = 0;
   
+  /* Figure out which stage of the druid we're in. */
   if((current = g_list_find(wind->pre_comm_pages, page)) == NULL) {
     if((current = g_list_find(wind->commodity_pages, page)) == NULL) {
       if((current = g_list_find(wind->post_comm_pages, page)) == NULL) {
-        /* where are we? */
+        /* Where are we? */
         printf("QIF import: I'm lost!\n");
         return FALSE;
       }
@@ -280,14 +297,26 @@ get_prev_druid_page(QIFImportWindow * wind, GnomeDruidPage * page)
     where = 1;
   }
   
-  prev = current->prev;
-  while(!prev ||
-        (!wind->show_doc_pages &&
-         g_list_find(wind->doc_pages, prev->data))) {
+  /* If no duplicates were found, skip all post-conversion pages. */
+  if (where == 3 && SCM_NULLP(wind->match_transactions))
+    prev = NULL;
+  else
+    prev = current->prev;
+
+  /* Keep going back through the sets of available pages as long as:
+   * (a) there are no remaining pages in this set, or
+   * (b) the page is a doc page and we're not supposed to show them, or
+   * (c) the page is commodity related and the are no new commodities. */
+  while (!prev ||
+         (!wind->show_doc_pages && g_list_find(wind->doc_pages, prev->data)) ||
+         (wind->new_stocks == SCM_BOOL_F &&
+          GNOME_DRUID_PAGE(prev->data) == get_named_page(wind, "commodity_doc_page"))) {
     if(prev && prev->prev) {
+      /* Go back another page within the same stage. */
       prev = prev->prev;
     }
     else {
+      /* Start looking at the end of the previous stage. */
       where --;
       switch(where) {
       case 1:
@@ -701,7 +730,9 @@ gnc_ui_qif_import_select_loaded_file_cb (GtkTreeSelection *selection,
   GtkTreeModel *model;
   GtkTreeIter iter;
   gint row;
+  GtkWidget *button;
 
+  button = gnc_glade_lookup_widget(wind->window, "unload_file_button");
   if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
     gtk_tree_model_get(model, &iter, FILENAME_COL_INDEX, &row, -1);
     if(SCM_LISTP(wind->imported_files) && 
@@ -710,11 +741,17 @@ gnc_ui_qif_import_select_loaded_file_cb (GtkTreeSelection *selection,
       wind->selected_file = scm_list_ref(wind->imported_files,
 					 scm_int2num(row));   
       scm_gc_protect_object(wind->selected_file);
+      g_object_set(button, "sensitive", TRUE, (gchar*)NULL);
+      gnome_druid_set_buttons_sensitive(GNOME_DRUID(wind->druid),
+                                        TRUE, TRUE, TRUE, TRUE);
     } 
   } else {
     scm_gc_unprotect_object(wind->selected_file);
     wind->selected_file = SCM_BOOL_F;
     scm_gc_protect_object(wind->selected_file);
+      g_object_set(button, "sensitive", FALSE, (gchar*)NULL);
+    gnome_druid_set_buttons_sensitive(GNOME_DRUID(wind->druid),
+                                      FALSE, TRUE, TRUE, TRUE);
   }
 }
 
@@ -731,9 +768,9 @@ gnc_ui_qif_import_loaded_files_prepare_cb(GnomeDruidPage * page,
 {
   QIFImportWindow * wind = user_data;
 
-  update_file_page(wind);
   gnome_druid_set_buttons_sensitive(GNOME_DRUID(wind->druid),
-                                    FALSE, TRUE, TRUE, TRUE); 
+                                    FALSE, TRUE, TRUE, TRUE);
+  update_file_page(wind);
 }
 
 
@@ -860,6 +897,7 @@ gnc_ui_qif_import_default_acct_next_cb(GnomeDruidPage * page,
   SCM    fix_default = scm_c_eval_string("qif-import:fix-from-acct");
   SCM    scm_name;
 
+  g_return_val_if_fail(wind->selected_file != SCM_BOOL_F, FALSE);
   if(!acct_name || acct_name[0] == 0) {
     gnc_warning_dialog(wind->window, _("You must enter an account name."));
     return TRUE;
@@ -1196,6 +1234,41 @@ gnc_ui_qif_import_categories_prepare_cb(GnomeDruidPage * page,
   gnc_unset_busy_cursor(NULL);
 }
 
+/****************************************************************
+ * gnc_ui_qif_import_categories_next_cb
+ * Check to see if there are any payees and memos to show. If not
+ * jump to currency page.
+ ****************************************************************/
+static gboolean
+gnc_ui_qif_import_categories_next_cb(GnomeDruidPage * page,
+                                     gpointer arg1,
+                                     gpointer user_data)
+{
+  QIFImportWindow * wind = user_data;
+  SCM  make_memo_display = scm_c_eval_string("qif-dialog:make-memo-display");
+  SCM  accts_left;
+  
+  gnc_set_busy_cursor(NULL, TRUE);
+  /*
+   * Hack. Call make-memo-display to see if there are any memos to display.
+   * This will get called again when we actually do make the memo display.
+   */
+  accts_left = scm_call_3(make_memo_display,
+			  wind->imported_files,
+			  wind->memo_map_info,
+			  wind->gnc_acct_info);
+  
+  gnc_unset_busy_cursor(NULL);
+  
+  if (SCM_NULLP(accts_left)) {
+    gnome_druid_set_page(GNOME_DRUID(wind->druid),
+                         get_named_page(wind, "currency_page"));
+    return TRUE;
+  } else {
+      return gnc_ui_qif_import_generic_next_cb(page, arg1, user_data);
+  }
+}
+
 /********************************************************************
  * gnc_ui_qif_import_memo_prepare_cb
  ********************************************************************/
@@ -1438,7 +1511,29 @@ gnc_ui_qif_import_memo_next_cb(GnomeDruidPage * page,
   }
 }
 
+/****************************************************************
+ * gnc_ui_qif_import_currency_back_cb
+ * Check to see if there are any payees and memos to show. If not
+ * jump to category match page.
+ ****************************************************************/
+static gboolean
+gnc_ui_qif_import_currency_back_cb(GnomeDruidPage * page, gpointer arg1, 
+                                  gpointer user_data)
+{
+  QIFImportWindow * wind = user_data;
   
+  if (!wind->memo_display_info ||
+      (wind->memo_display_info == SCM_BOOL_F) ||
+       SCM_NULLP(wind->memo_display_info))
+  {
+    gnome_druid_set_page(GNOME_DRUID(wind->druid),
+                         get_named_page(wind, "category_match_page"));
+    return TRUE;
+  } else {
+      return gnc_ui_qif_import_generic_back_cb(page, arg1, user_data);
+  }
+}
+
 /********************************************************************
  * gnc_ui_qif_import_currency_next_cb
  ********************************************************************/
@@ -1626,6 +1721,10 @@ gnc_ui_qif_import_commodity_prepare_cb(GnomeDruidPage * page,
     #undef FUNC_NAME
     new_page = make_qif_druid_page(commodity);
 
+    g_signal_connect(new_page->page, "back",
+		     G_CALLBACK(gnc_ui_qif_import_generic_back_cb),
+		     wind);
+
     g_signal_connect(new_page->page, "next",
 		     G_CALLBACK(gnc_ui_qif_import_comm_check_cb),
 		     wind);
@@ -2044,7 +2143,11 @@ gnc_ui_qif_import_druid_make(void)
   glade_xml_signal_connect_data
     (xml, "gnc_ui_qif_import_categories_prepare_cb",
      G_CALLBACK (gnc_ui_qif_import_categories_prepare_cb), retval);
-
+  
+  glade_xml_signal_connect_data
+    (xml, "gnc_ui_qif_import_categories_next_cb",
+     G_CALLBACK (gnc_ui_qif_import_categories_next_cb), retval);
+  
   glade_xml_signal_connect_data
     (xml, "gnc_ui_qif_import_memo_prepare_cb",
      G_CALLBACK (gnc_ui_qif_import_memo_prepare_cb), retval);
@@ -2052,7 +2155,11 @@ gnc_ui_qif_import_druid_make(void)
   glade_xml_signal_connect_data
     (xml, "gnc_ui_qif_import_memo_next_cb",
      G_CALLBACK (gnc_ui_qif_import_memo_next_cb), retval);
-
+  
+  glade_xml_signal_connect_data
+    (xml, "gnc_ui_qif_import_currency_back_cb",
+     G_CALLBACK (gnc_ui_qif_import_currency_back_cb), retval);
+  
   glade_xml_signal_connect_data
     (xml, "gnc_ui_qif_import_currency_next_cb",
      G_CALLBACK (gnc_ui_qif_import_currency_next_cb), retval);
