@@ -6,13 +6,16 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define-module (gnucash import-export qif-import))
-(use-modules (gnucash main) (g-wrapped gw-gnc)) ;; FIXME: delete after we finish modularizing.
+(use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
+
+;; We do this initialization here because src/gnome isn't a real module.
+(load-extension "libgnc-gnome" "scm_init_sw_gnome_module")
+(use-modules (sw_gnome))
 
 (use-modules (gnucash gnc-module))
 (use-modules (ice-9 slib))
 (use-modules (ice-9 regex))
 (use-modules (srfi srfi-1))
-(use-modules (g-wrap gw-wct))
 
 (debug-enable 'debug)
 (debug-enable 'backtrace)
@@ -62,6 +65,6 @@
 (export qif-dialog:make-category-display)
 (export qif-dialog:make-memo-display)
 
-(export gnc:group-find-duplicates)
-(export gnc:group-catenate-and-merge)
+(export gnc:account-tree-find-duplicates)
+(export gnc:account-tree-catenate-and-merge)
 (export gnc:prune-matching-transactions)
