@@ -25,7 +25,6 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include "Group.h"
 #include "datecell.h"
 #include "dialog-utils.h"
 #include "gnc-engine.h"
@@ -83,7 +82,7 @@ gnc_split_register_use_security_cells (SplitRegister *reg,
     const char *name;
 
     name = gnc_table_layout_get_cell_value (reg->table->layout, XFRM_CELL);
-    account = xaccGetAccountFromFullName (gnc_get_current_group (), name);
+    account = gnc_account_lookup_by_full_name (gnc_get_current_root_account (), name);
   }
 
   if (!account)
@@ -790,7 +789,7 @@ gnc_split_register_get_date_help (VirtualLocation virt_loc,
 
   tm = localtime (&tt);
 
-  strftime (string, sizeof (string), "%A %d %B %Y", tm);
+  qof_strftime (string, sizeof (string), "%A %d %B %Y", tm);
 
   return g_strdup (string);
 }
@@ -1647,7 +1646,7 @@ gnc_split_register_confirm (VirtualLocation virt_loc, gpointer user_data)
   char recn;
 
   /* This assumes we reset the flag whenever we change splits.
-   * This happens in LedgerMoveCursor. */
+   * This happens in gnc_split_register_move_cursor(). */
   if (info->change_confirmed)
     return TRUE;
 
@@ -1676,7 +1675,7 @@ gnc_split_register_confirm (VirtualLocation virt_loc, gpointer user_data)
     /* Does the user want to be warned? */
     window = gnc_split_register_get_parent(reg);
     dialog =
-      gtk_message_dialog_new_with_markup(GTK_WINDOW(window),
+      gtk_message_dialog_new(GTK_WINDOW(window),
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_WARNING,
 					 GTK_BUTTONS_CANCEL,
@@ -1691,7 +1690,6 @@ gnc_split_register_confirm (VirtualLocation virt_loc, gpointer user_data)
       return FALSE;
 
     info->change_confirmed = TRUE;
-    return TRUE;
   }
 
   return TRUE;
@@ -1739,7 +1737,7 @@ gnc_template_register_get_xfrm_entry (VirtualLocation virt_loc,
 
     account = xaccAccountLookup (guid, gnc_get_current_book ());
 
-    name = xaccAccountGetFullName (account);
+    name = account ? xaccAccountGetFullName(account) : NULL;
   }
   else
     name = NULL;
@@ -1904,6 +1902,10 @@ gnc_split_register_model_add_hooks (gpointer unused)
   gnc_gconf_general_register_cb(KEY_NEGATIVE_IN_RED,
 				gnc_split_register_colorize_negative,
 				NULL);
+  /* Get the initial value */
+  use_red_for_negative = gnc_gconf_get_bool(GCONF_GENERAL, 
+                                            KEY_NEGATIVE_IN_RED, 
+                                            NULL);
   return NULL;
 }
 
@@ -2161,8 +2163,8 @@ gnc_split_register_model_new (void)
 
   /* FIXME: We really only need a due date for 'invoices', not for
    * 'payments' or 'receipts'.  This implies we really only need the
-   * due-date for transactions that credit the RECEIVABLE or debit
-   * the PAYABLE account type.
+   * due-date for transactions that credit the ACCT_TYPE_RECEIVABLE or
+   * debit the ACCT_TYPE_PAYABLE account type.
    */
   gnc_table_model_set_io_flags_handler(
       model, gnc_split_register_get_rate_io_flags, RATE_CELL);
