@@ -35,7 +35,6 @@
 #include "gnc-engine.h"
 #include "gnucash-item-list.h"
 #include "gnucash-scrolled-window.h"
-#include "gtk-compat.h"
 
 /* Item list signals */
 enum {
@@ -460,7 +459,10 @@ gnc_item_list_new(GnomeCanvasGroup *parent, GtkListStore *list_store)
 
 	if (NULL == list_store)
 		list_store = gtk_list_store_new (1, G_TYPE_STRING);
+	else
+		g_object_ref(list_store);
 	tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list_store));
+	g_object_unref(list_store);
 	/* Removed code to enable sorting. Enable it after the list is
 	 * fully populated by calling gnc_item_list_finished_loading(). */
  
