@@ -41,11 +41,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include "gtk-compat.h"
-#ifndef HAVE_GLIB26
-#include "gkeyfile.h"
-#endif
-#include <g-wrap-wct.h>
+#include <glib/gstdio.h>
 #include <libguile.h>
 #include <sys/stat.h>
 #include <errno.h>
@@ -58,16 +54,17 @@
 #include "gnc-html-history.h"
 #include "gnc-html.h"
 #include "gnc-file.h"
-#include "gnc-gkeyfile-utils.h"
 #include "gnc-plugin.h"
 #include "gnc-plugin-page-report.h"
 #include "gnc-report.h"
+#include "gnc-session.h"
 #include "gnc-ui-util.h"
 #include "gnc-ui.h"
 #include "gnc-window.h"
 #include "guile-util.h"
 #include "option-util.h"
 #include "window-report.h"
+#include "swig-runtime.h"
 
 #define WINDOW_REPORT_CM_CLASS "window-report"
 
@@ -89,6 +86,7 @@ typedef struct GncPluginPageReportPrivate
 {
         /// The report-id
         int reportId;
+        gint component_manager_id;
 
         /// The report which this Page is satisifying
         SCM cur_report;
@@ -320,6 +318,8 @@ gnc_plugin_page_report_create_widget( GncPluginPage *page )
         char * url_location = NULL;
         char * url_label = NULL;
 
+	ENTER("page %p", page);
+
         report = GNC_PLUGIN_PAGE_REPORT(page);
         priv = GNC_PLUGIN_PAGE_REPORT_GET_PRIVATE(report);
 
@@ -336,8 +336,11 @@ gnc_plugin_page_report_create_widget( GncPluginPage *page )
         gtk_container_add(GTK_CONTAINER(priv->container), 
                           gnc_html_get_widget(priv->html));
   
-        gnc_register_gui_component( WINDOW_REPORT_CM_CLASS, NULL,
-                                    close_handler, priv );
+        priv->component_manager_id =
+          gnc_register_gui_component(WINDOW_REPORT_CM_CLASS, NULL,
+                                     close_handler, page);
+        gnc_gui_component_set_session(priv->component_manager_id,
+                                      gnc_get_current_session());
   
         gnc_html_set_urltype_cb(priv->html, gnc_plugin_page_report_check_urltype);
         gnc_html_set_load_cb(priv->html, gnc_plugin_page_report_load_cb, report);
@@ -348,7 +351,9 @@ gnc_plugin_page_report_create_widget( GncPluginPage *page )
         child_name = gnc_build_url( URL_TYPE_REPORT, id_name, NULL );
         type = gnc_html_parse_url( priv->html, child_name, &url_location, &url_label);
         DEBUG( "passing id_name=[%s] child_name=[%s] type=[%s], location=[%s], label=[%s]",
-               id_name, child_name, type, url_location, url_label );
+               id_name, child_name ? child_name : "(null)",
+               type ? type : "(null)", url_location ? url_location : "(null)",
+               url_label ? url_label : "(null)" );
 
         gnc_window_set_progressbar_window( GNC_WINDOW(page->window) );
         gnc_html_show_url(priv->html, type, url_location, url_label, 0);
@@ -359,6 +364,8 @@ gnc_plugin_page_report_create_widget( GncPluginPage *page )
   
         gtk_widget_show_all( GTK_WIDGET(priv->container) );
 
+	LEAVE("container %p", priv->container);
+
         return GTK_WIDGET( priv->container );
 }
 
@@ -432,7 +439,8 @@ gnc_plugin_page_report_load_cb(gnc_html * html, URLType type,
         SCM  inst_report;
 
         ENTER( "load_cb: type=[%s], location=[%s], label=[%s]",
-               type, location, label );
+               type ? type : "(null)", location ? location : "(null)",
+               label ? label : "(null)" );
 
         /* we get this callback if a new report is requested to be loaded OR
          * if any URL is clicked.  If an options URL is clicked, we want to
@@ -454,6 +462,7 @@ gnc_plugin_page_report_load_cb(gnc_html * html, URLType type,
                 if (inst_report != SCM_BOOL_F) {
                         gnc_plugin_page_report_add_edited_report(priv, inst_report);
                 }
+                LEAVE("");
                 return;
         } else {
                 LEAVE( " unknown URL type [%s] location [%s]", type, location );
@@ -639,15 +648,21 @@ gnc_plugin_page_report_destroy_widget(GncPluginPage *plugin_page)
 
         PINFO("destroy widget");
         priv = GNC_PLUGIN_PAGE_REPORT_GET_PRIVATE(plugin_page);
+
+        if (priv->component_manager_id) {
+                gnc_unregister_gui_component(priv->component_manager_id);
+                priv->component_manager_id = 0;
+        }
+
+        gnc_plugin_page_report_destroy(priv);
         gnc_report_remove_by_id(priv->reportId);
 }
 
 
 /** The key name used it the state file for storing the report
  *  options. */
-#define SCHEME_OPTIONS   "Scheme Options"
-#define SCHEME_OPTIONS_N "Scheme Options %d"
-#define SCHEME_OPTIONS_NEW "SchemeOptions"
+#define SCHEME_OPTIONS   "SchemeOptions"
+#define SCHEME_OPTIONS_N "SchemeOptions%d"
 
 
 /** Save enough information about this report page that it can be
@@ -761,10 +776,9 @@ gnc_plugin_page_report_recreate_page (GtkWidget *window,
 	}
 
 	for (i = 0; i < num_keys; i++) {
-	  if ((strncmp(keys[i], SCHEME_OPTIONS, strlen(SCHEME_OPTIONS)) != 0) &&
-	      (strncmp(keys[i], SCHEME_OPTIONS_NEW, strlen(SCHEME_OPTIONS_NEW)) != 0))
+	  if (strncmp(keys[i], SCHEME_OPTIONS, strlen(SCHEME_OPTIONS)) != 0)
 	    continue;
-	  option_string = gnc_key_file_get_string(key_file, group_name,
+	  option_string = g_key_file_get_string(key_file, group_name,
 						keys[i], &error);
 	  if (error) {
 	    g_warning("error reading group %s key %s: %s",
@@ -783,8 +797,7 @@ gnc_plugin_page_report_recreate_page (GtkWidget *window,
 	  }
 
 	  if (final_id == SCM_BOOL_F) {
-	    if ((strcmp(keys[i], SCHEME_OPTIONS) == 0) ||
-		(strcmp(keys[i], SCHEME_OPTIONS_NEW) == 0)) {
+	    if (strcmp(keys[i], SCHEME_OPTIONS) == 0) {
 	      final_id = scm_id;
 	    }
 	  }
@@ -838,7 +851,8 @@ gnc_plugin_page_report_name_changed (GncPluginPage *page, const gchar *name)
   /* Is this a redundant call? */
   old_name = gnc_option_db_lookup_string_option(priv->cur_odb, "General",
 						"Report name", NULL);
-  DEBUG("Comparing old name '%s' to new name '%s'", old_name, name);
+  DEBUG("Comparing old name '%s' to new name '%s'",
+	old_name ? old_name : "(null)", name);
   if (old_name && (strcmp(old_name, name) == 0)) {
     LEAVE("no change");
     return;
@@ -900,15 +914,18 @@ gnc_plugin_page_report_destroy(GncPluginPageReportPrivate * priv)
         SCM  set_editor = scm_c_eval_string("gnc:report-set-editor-widget!");
         SCM  edited, editor; 
 
-        gnc_unregister_gui_component_by_data (WINDOW_REPORT_CM_CLASS, priv);
-
         /* close any open editors */
         for (edited = scm_list_copy(priv->edited_reports); !SCM_NULLP(edited);
              edited = SCM_CDR(edited)) {
                 editor = scm_call_1(get_editor, SCM_CAR(edited));
                 scm_call_2(set_editor, SCM_CAR(edited), SCM_BOOL_F);
                 if (editor != SCM_BOOL_F) {
-                        gtk_widget_destroy(GTK_WIDGET(gw_wcp_get_ptr(editor)));
+                    GtkWidget *w = NULL;
+                    #define FUNC_NAME "gtk_widget_destroy"
+                    w = SWIG_MustGetPtr(editor,
+                                        SWIG_TypeQuery("_p_GtkWidget"), 1, 0);
+                    #undef FUNC_NAME
+                    gtk_widget_destroy(GTK_WIDGET(w));
                 }
         }
 
@@ -945,6 +962,9 @@ static GtkActionEntry report_actions[] =
         { "EditPasteAction", GTK_STOCK_PASTE, N_("_Paste"), NULL,
           N_("Paste the clipboard content at the cursor position"),
           NULL },
+	{ "ViewRefreshAction", GTK_STOCK_REFRESH, N_("_Refresh"), "<control>r",
+	  N_("Refresh this window"),
+	  G_CALLBACK (gnc_plugin_page_report_reload_cb) },
         { "ReportSaveAction", GTK_STOCK_SAVE, N_("Add _Report"), "", 
 	  N_("Add the current report to the `Custom' menu for later use. "
 	     "The report will be saved in the file ~/.gnucash/saved-reports-2.0. "
@@ -1105,15 +1125,19 @@ gnc_plugin_page_report_raise_editor(SCM report)
 {
         SCM get_editor = scm_c_eval_string("gnc:report-editor-widget");
         SCM editor = scm_call_1(get_editor, report);
-        gtk_window_present(gw_wcp_get_ptr(editor));
+        #define FUNC_NAME "gtk_window_present"
+        GtkWidget *w = SWIG_MustGetPtr(editor,
+                                       SWIG_TypeQuery("_p_GtkWidget"), 1, 0);
+        #undef FUNC_NAME
+        gtk_window_present(GTK_WINDOW(w));
 }
 
 static void
 close_handler (gpointer user_data)
 {
-        GncPluginPageReportPrivate *priv = user_data;  
+        GncPluginPage *plugin_page = GNC_PLUGIN_PAGE(user_data);
         DEBUG("in close handler\n");
-        gnc_plugin_page_report_destroy (priv);
+        gnc_main_window_close_page (plugin_page);
 }
 
 static void
@@ -1303,7 +1327,7 @@ gnc_get_export_filename (SCM choice)
         if (!filepath)
                 return NULL;
 
-        rc = stat (filepath, &statbuf);
+        rc = g_stat (filepath, &statbuf);
 
         /* Check for an error that isn't a non-existant file. */
         if (rc != 0 && errno != ENOENT)
@@ -1352,6 +1376,14 @@ gnc_plugin_page_report_save_cb( GtkAction *action, GncPluginPageReport *report )
 
 	save_func = scm_c_eval_string("gnc:report-save-to-savefile");
 	scm_call_1(save_func, priv->cur_report);
+
+	{
+	  GtkActionGroup *action_group =
+	    gnc_plugin_page_get_action_group(GNC_PLUGIN_PAGE(report));
+	  GtkAction *action =
+	    gtk_action_group_get_action (action_group, "ReportSaveAction");
+	  gtk_action_set_sensitive(action, FALSE);
+	}
 }
 
 static void
