@@ -136,14 +136,14 @@
     (map
      (lambda (elt)
        (cond ((number? elt)
-              (abs elt))
+              (exact->inexact (abs elt)))
              ((string? elt)
               (with-input-from-string elt
                 (lambda ()
                   (let ((n (read)))
                     (if (number? n) (abs n) 0.0)))))
              ((gnc:gnc-numeric? elt)
-              (abs (gnc:numeric-to-double elt)))
+              (abs (gnc-numeric-to-double elt)))
              (#t 
               0.0)))
      nlist))
