@@ -106,8 +106,10 @@
 (export gnc:define-report)
 (export <report>)
 (export gnc:report-template-new-options/name)
+(export gnc:report-template-new-options/report-guid)
 (export gnc:report-template-menu-name/name)
 (export gnc:report-template-renderer/name)
+(export gnc:report-template-renderer/report-guid)
 (export gnc:report-template-new-options)
 (export gnc:report-template-version)
 (export gnc:report-template-name)
@@ -137,6 +139,7 @@
 (export gnc:report-set-ctext!)
 (export gnc:make-report)
 (export gnc:restore-report)
+(export gnc:restore-report-by-guid)
 (export gnc:make-report-options)
 (export gnc:report-export-types)
 (export gnc:report-export-thunk)
